% GUISPERT.m: special hacks - makes some more space available
% GUISDAP v1.60   96-05-27 Copyright Asko Huuskonen, Markku Lehtinen
%
% script for GUISPERTs and other power users. Put here any commands by
% which you wish to change the data before the analysis is started
%
% See also: GUIZARD
%
% Removing uncessary variables
%
% %W% %D%
%
% 8/98 placed under change control
%
d_var1=real(d_var1);
clear lpg_wom vc_Aenv vc_Apenv vc_penvabs vc_penv vc_penvo

if strcmp(name_expr,'gup1')
  fprintf(' GUISPERT gup1 : scaling alternating codes\n')
  % The alternating code signal data has been scaled by 4
  lpgs=find((lpg_code>=5 & lpg_code<=8) & lpg_bcs=='s');
  addr=lpg_addr(lpgs);
  d_data(addr+1)=4*d_data(addr+1);
  d_var1(addr+1)=16*d_var1(addr+1);
  d_var2(addr+1)=16*d_var2(addr+1);
  % Combine the background and calibration data blocks for AC
  fprintf(' GUISPERT gup1 : combining alternating code calibrations\n')
  for code=5:8
    % Background
    lpgs=find(lpg_code==code & lpg_bcs=='b' & lpg_lag==0);
    addr1=lpg_addr(lpgs(1));
    addr2=lpg_addr(lpgs(2));
    d_data(addr1+1)=(d_data(addr1+1)+d_data(addr2+1))/2;
    d_var1(addr1+1)=(d_var1(addr1+1)+d_var1(addr2+1))/4;
    d_var2(addr1+1)=(d_var2(addr1+1)+d_var2(addr2+1))/4;
    % Calibration
    lpgs=find(lpg_code==code & lpg_bcs=='c' & lpg_lag==0);
    addr1=lpg_addr(lpgs(1));
    addr2=lpg_addr(lpgs(2));
    d_data(addr1+1)=(d_data(addr1+1)+d_data(addr2+1))/2;
    d_var1(addr1+1)=(d_var1(addr1+1)+d_var1(addr2+1))/4;
    d_var2(addr1+1)=(d_var2(addr1+1)+d_var2(addr2+1))/4;
  end
end

if strcmp(name_expr,'gup1') |  strcmp(name_expr,'gup0')
  if name_expr=='gup1', maxcode=4; else maxcode=8; end
  fprintf(' GUISPERT gup0/1 : combining long pulse calibrations\n')
  for code=1:maxcode
    lagvalues=diff_val(lpg_lag(find(lpg_code==code & lpg_bcs=='b')));
    for lags=lagvalues
      lpgs=find(lpg_code==code & lpg_bcs=='b' & lpg_lag==lags);
	  addr1=lpg_addr(lpgs(1));
	  addr2=lpg_addr(lpgs(2));
      d_data(addr1+1)=(d_data(addr1+1)+d_data(addr2+1))/2;
      d_var1(addr1+1)=(d_var1(addr1+1)+d_var1(addr2+1))/4;
      d_var2(addr1+1)=(d_var2(addr1+1)+d_var2(addr2+1))/4;
    end
    lpgs=find(lpg_code==code & lpg_bcs=='c' & lpg_lag==0);
    addr1=lpg_addr(lpgs(1));
    addr2=lpg_addr(lpgs(2));
    d_data(addr1+1)=(d_data(addr1+1)+d_data(addr2+1))/2;
    d_var1(addr1+1)=(d_var1(addr1+1)+d_var1(addr2+1))/4;
    d_var2(addr1+1)=(d_var2(addr1+1)+d_var2(addr2+1))/4;
  end
end

%
% after mid-February 1998, the tx power was doubled, but this is not
% reflected in the datadumps until 26 February - should affect only the
% French SP of February 22nd.
%
if datenum(d_time(1,1),d_time(1,2),d_time(1,3)) >= datenum(1998,2,10) ...
   & datenum(d_time(1,1),d_time(1,2),d_time(1,3)) <= datenum(1998,2,25) 
  d_parbl(8) = d_parbl(8) * 2.0;
  fprintf(' GUISPERT: doubled power estimate to %4i kW\n', fix(d_parbl(8)/1000))
end

if strcmp(name_expr,'tau0')
  fprintf(' GUISPERT tau0 : reorganising and deweighting d_data\n')
  d_data = tau02gup(d_data);
  d_var1 = tau02gup(d_var1);
  d_var2 = tau02gup(d_var2);
end

%
% Replace following with values from d_parbl as soon as possible!
%
% after 24 February 2000, the calibration temperature on the 32m
% system rose by 8 K from 220 to 228K 
%
if datenum(d_time(1,1),d_time(1,2),d_time(1,3)) >= datenum(2000,2,25) ...
   & antennaEfficiency < 0.65
  calTemp = 228;
end
fprintf(' GUISPERT: Calibration injection temperature set to %4i K\n', calTemp )
fprintf(' GUISPERT: Antenna efficiency  set to %4i\n', antennaEfficiency )
 
%
% Setup antenna gain and calibration injection for ESR antennas
%
%if length(d_parbl) < 21
%  calTemp = 0; 
%else
%  calTemp = d_parbl(21);
%end
% Antenna efficiency is the ratio of the true gain and the
% theoretical gain 4*pi*A/lambda^2
%if length(d_parbl) < 41
%  % 32m antenna
%  antennaEfficiency = 0.633; % 42,5 dBi gain
%  if calTemp == 0
%    calTemp = 220;
%    fprintf(' GUISPERT: Calibration injection temperature set to %4i K\n', calTemp )
%  end
%elseif d_parbl(41) == 1
%  % 32m antenna
%  antennaEfficiency = 0.633; % 42,5 dBi gain
%  if calTemp == 0
%    calTemp = 220;
%    fprintf(' GUISPERT: Calibration injection temperature set to %4i K\n', calTemp )
%  end
%elseif  d_parbl(41) == 2
%  % 42m antenna
%  antennaEfficiency = 0.685; % 45.2 dBi gain
%  if calTemp == 0
%    calTemp = 148;
%    fprintf(' GUISPERT: Calibration injection temperature set to %4i K\n', calTemp )
%  end
%else
%  error('Illegal antenna specification in parameter block location 41')
%end


