% save_results.m: function to store whole profile of results into a file
% GUISDAP v.1.60 96-05-27 Copyright Asko Huuskonen and Markku Lehtinen
%
% 8/98 added result vector r_NCARvel_PosAway containing los velocities
%      with NCAR sign convention
% 
% @(#)save_results.m	1.4 00/01/20
% function save_results
  function save_results

global data_path result_path name_expr name_site analysis_integr codes_selected
global p_XMITloc p_RECloc sc_angle
global d_time GUP_ver ch_az ch_el ch_Pt p_m0 p_N0 p_dtau v_lightspeed
global r_ver r_time r_az r_el r_Pt r_m0 r_h r_SCangle
global r_ind r_range r_param r_error r_res r_status r_dp
global r_apriori r_apriorierror
global pp_range pp_sigma

% construct result folder name and create if necessary
result_path = sprintf('%sanalysis/%d-%02d-%02d_%s_%s_%d/', ...
    data_path, d_time(1,1:3), name_expr, codes_selected, analysis_integr);
if ~exist( result_path )
  eval (['!mkdir ',result_path]);
end

% construct result file name
filename='00000000';
if length(d_time)>0,
  file=int2str(tosecs(d_time(2,:)));len=length(file);
  filename(9-len:8)=file;
end
file=canon([result_path, filename]);

r_ver=GUP_ver;
r_time=d_time;
r_az=ch_az(1);
r_el=ch_el(1);
r_Pt=ch_Pt(1);
r_m0=p_m0;
r_XMITloc=p_XMITloc;
r_RECloc=p_RECloc;
r_SCangle=sc_angle/2;

r_pp=pp_sigma*p_N0;
r_pprange=col(pp_range)*(p_dtau*1e-6*v_lightspeed/2/1000);

r_h=col(range_to_height(r_range,ch_el(1)));
r_range=col(r_range)*(p_dtau*1e-6*v_lightspeed/2/1000);

r_NCARvel_PosAway=-r_param(:,5);

variables=['r_ver name_expr name_site r_time r_az r_el r_Pt r_m0'];
variables= [variables ' r_range r_h r_param r_NCARvel_PosAway r_error r_res'];
variables= [variables ' r_status r_dp r_apriori r_apriorierror r_pp'];
variables= [variables ' r_pprange r_XMITloc r_RECloc r_SCangle'];

eval(['save ', file, '.mat ' variables])
% save file name to "filelist.dat"
fprintf(canon([result_path 'filelist.dat'],0),[filename,'\n']);
