% NCAR_output_velocity.m
%
% Optionally:
% Writes profile of results in NCAR binary and/or asciiformat to the www 
% server areas and/or: appends profiles of results in NCAR ascii format to a 
% concatented file ready to read into MADRIGAL, etc. 
%
%--------------------------------------------------------------------------
%     COPYRIGHT 2000 EISCAT SCIENTIFIC ASSOCIATION.
%     PERMISSION TO USE, COPY, AND DISTRIBUTE, FOR NON-COMMERCIAL PURPOSES,
%     IS HEREBY GRANTED WITHOUT FEE, PROVIDED THAT THIS LICENSE INFORMATION
%     AND COPYRIGHT NOTICE APPEAR IN ALL COPIES.
%--------------------------------------------------------------------------
% works with GUISDAP v.1.65 
%
% %W% %D%
%
function NCAR_output_velocities

global data_path result_path name_expr name_site analysis_integr codes_selected antenna_selected
global p_XMITloc p_RECloc sc_angle
global d_time GUP_ver ch_az ch_el ch_Pt p_m0 p_N0 p_dtau v_lightspeed
global r_ver r_time r_az r_el r_Pt r_m0 r_h r_SCangle
global r_ind r_range r_param r_error r_res r_status r_dp
global r_apriori r_apriorierror
global pp_range pp_sigma
global d_parbl

% output files.  Set any file to zero length to disable that output
NCAR_ascii_single_record       = '/tmp/NCAR_EISCAT_L_VELOCITY';
NCAR_binary_single_record      = '/esrsw/www/htdocs/tmp/NCAR_EISCAT_LB_velocity';
NCAR_output_file_concatenated  = sprintf('/data/analysis/NCAR_%d-%02d-%02d_%s_%s_%d_%dm_velocity/', ...
    d_time(1,1:3), name_expr, codes_selected, analysis_integr, antenna_selected);

% set up absent data value
AbsentData                      = -32767;

dtr 				= 0.0174532925199d0;

% set up NCAR single-valued parameters 
Azimuth				= 130;
Elevation			= 140;
Scattering_half_angle		= 190;
System_temperature		= 482;
Peak_transmitted_power		= 486; % kW

% set up NCAR multi-valued parameters 
Altitude 			= 110;
Geodetic_latitude		= 160;
Geodetic_longitude		= 170;
snr				= 410;	
Log10_Ne			= 520;
Ti				= 550;
TeTi				= 570;
Vi				= 580;
error_Log10_Ne			=-520;
error_Ti			=-550;
error_TeTi			=-570;
error_Vi			=-580;
vel_dir_azimuth			= 600;
vel_dir_elevation		= 610;

switch name_site 
  case 'L',   KINST = 95;                  % NCAR instrumant code: EISCAT Svalbard Radar
              sgdlat = 78.158; 	           % values from GPS
              slon =   16.029;
              sgdalt =  0.438;
  case 'K',   KINST = 71;                  %                       EISCAT Kiruna UHF
  case 'T',   KINST = 72;                  %                       EISCAT Tromso UHF
  case 'S',   KINST = 73;                  %                       EISCAT Sodankyla UHF
  case 'V',   KINST = 74;                  %                       EISCAT Tromso VHF
  otherwise,  KINST = AbsentData;          %                       unknown
end    
if ( KINST == 95)
  KINDAT=6800 + 10*str2num(name_expr(length(name_expr))) + 1; % eg: 6831 = GUP3, first code (ac)
else
  KINDAT=6000 + 100*str2num(name_expr(length(name_expr)-1)) + 2; % eg: 6302 = CP3, version 1
end
IBYR	=fix(r_time(1,1));		   % beginning year
IBDT	=fix(r_time(1,2)*100+r_time(1,3)); % beginning date
IBHM	=fix(r_time(1,4)*100+r_time(1,5)); % beginning hour & min
IBCS	=fix(r_time(1,6)*100);		   % beginning centisecond
IEYR	=fix(r_time(2,1));		   % ending year
IEDT	=fix(r_time(2,2)*100+r_time(2,3)); % ending date
IEHM	=fix(r_time(2,4)*100+r_time(2,5)); % ending hour & min
IECS	=fix(r_time(2,6)*100);		   % ending centisecond
LPROL	=16;				   % length of prologue
JPAR	=5;				   % # single-valued parameters
MPAR	=8;				   % # multi-valued parameters	
NROW	=length(r_h);			   % # entries for each multi-valued parameter

% calculate necessary out put parameters for SuperDARN (this is basically dircos.m)

% Cast azimuth and elevation into range +-180, 0-90 degrees
   
if ( r_el > 90.0 )
  m_el = 180.0 - r_el;
  m_az = r_az + 180.00;
else
  m_el = r_el;
  m_az = r_az;   
end
m_az = mod((m_az + 360.0), 360.0);
if ( m_az > 180.0 )
  m_az = m_az - 360.0;
end
 
% convert station coordinates from geodetic to geocentric
      gclat = []; rkm = [];
      [ sgdlat,sgdalt,gclat,rkm  ] = convrt( 1,sgdlat,sgdalt,gclat,rkm );

     
% Assemble output vector of codes and values for the multi-valued parameters

Output_vector = [Geodetic_latitude,Geodetic_longitude,Altitude,vel_dir_azimuth,vel_dir_elevation, ...
                          snr,Vi,error_Vi];

for Ic = 1:NROW

      % Compute geocentric coordinates at selected point
      pr=[]; pgclat=[]; plon=[];
      [pr,pgclat,plon] = point(rkm,gclat,slon,m_az,m_el,r_range(Ic),pr,pgclat,plon);
      
      % Convert observation point coordinates from geocentric to geodetic
      plat=[]; palt=[];
      [ plat,palt,glat,pr  ] = convrt( 2,plat,palt,pgclat,pr );
 
   if ( r_status(Ic) == 0 )
      % only output results for fit parameter 0
 
      % Convert radar propagation vector and observation point position to
      % Earth centered Cartesian co-ordinates
      rfx=[]; rfy=[]; rfz=[]; pfx=[]; pfy=[]; pfz=[];
      [rfx,rfy,rfz,pfx,pfy,pfz] = rpcart(rkm,gclat,slon,m_az,m_el,r_range(Ic),rfx,rfy,rfz,pfx,pfy,pfz);
      
      % calculate direction cosines of radar beam with respect to
      % geocentric south, east, up
      rfr=[]; rft=[]; rfp=[]; rr=[]; rt=[]; rp=[];       
      [ rfx,rfy,rfz,pfx,pfy,pfz,rfr,rft,rfp,rr,rt,rp ] = vctcnv(rfx,rfy,rfz,pfx,pfy,pfz,rfr,rft,rfp,rr,rt,rp,1);
     
      cst = rft/r_range(Ic);
      csp = rfp/r_range(Ic);
      csr = rfr/r_range(Ic);
     
      % Compute geodetic direction cosines.  The direction cosines
      % are with respect to x (North), y (East) and z (down).
      cx=[]; cy=[]; cz=[];
      [ cx,cy,cz ] = gdv(plat,pgclat,csr,cst,csp,cx,cy,cz); 
    
      elk = -asin(cz)/dtr;
      azk = atan2(cy,cx)/dtr;
    
      Output_vector = [Output_vector,round(plat*100)];
      Output_vector = [Output_vector,round(plon*100)];
      Output_vector = [Output_vector,round(palt)];
      Output_vector = [Output_vector,round(azk*100)];
      Output_vector = [Output_vector,round(elk*100)];
      Output_vector = [Output_vector,AbsentData];
      % invert sign of GUISDAP velocities to match NCAR convention
      Output_vector = [Output_vector,round(-r_param(Ic,5))];
      Output_vector = [Output_vector,round(r_error(Ic,5))];
   else
      % otherwise output position plus absent data values
      Output_vector = [Output_vector,round(plat*100)];
      Output_vector = [Output_vector,round(plon*100)];
      Output_vector = [Output_vector,round(palt)];
      for Icc = 1:(MPAR-3)
          Output_vector = [Output_vector,AbsentData];
      end
   end
end

% replace infinities and all values > 32767, i.e. larger than a
% signed short, by AbsentData value

Ik = [find(Output_vector == Inf), ...
      find(Output_vector == -Inf), ...
      find(abs(Output_vector) > 32767) ];
Output_vector(Ik) = AbsentData*ones(size(Ik));
 
if length(NCAR_ascii_single_record) > 0  
  
  % Open the single record ncar output file, ascii, overwrite mode

  [fid_NCAR_output_file, message] = fopen(NCAR_ascii_single_record,'w');

  KREC	=1101;				   % kind of record (data, character version)
  LTOT  =1+fix((JPAR+19)/20)*2+fix((MPAR+19)/20)*(NROW+1); % number of lines in record

  % Write the prologue

  fprintf(fid_NCAR_output_file, ...
      '%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i\n', ...
      LTOT,KREC,KINST,KINDAT,IBYR,IBDT,IBHM,IBCS, ...
      IEYR,IEDT,IEHM,IECS,LPROL,JPAR,MPAR,NROW);
    
  % Write codes and values for the single-valued parameters

  fprintf(fid_NCAR_output_file, ...
      '%6i%6i%6i%6i%6i\n', ...
      Azimuth,Elevation,Scattering_half_angle,System_temperature, ...
      Peak_transmitted_power,round(m_az*100),round(m_el*100), ...
      AbsentData,AbsentData,round(d_parbl(8)/1000.0));
  
  % Write codes and values for the multi-valued parameters
  
  fprintf(fid_NCAR_output_file, ...
      '%6i%6i%6i%6i%6i%6i%6i%6i\n', ...
      Output_vector);
    
  % close the file
  
  status = fclose(fid_NCAR_output_file);

end

if length(NCAR_binary_single_record) > 0  
  
  % Open the single record ncar output file, binary, overwrite mode

  [fid_NCAR_output_file, message] = fopen(NCAR_binary_single_record,'wb');

  KREC	=1002;				   % kind of record (data, binary version)
  LTOT	=20+2*JPAR+MPAR*(NROW+1);	   % number of entries

  % Write the prologue

  fwrite(fid_NCAR_output_file, ...
      [LTOT,KREC,KINST,KINDAT,IBYR,IBDT,IBHM,IBCS, ...
	IEYR,IEDT,IEHM,IECS,LPROL,JPAR,MPAR,NROW], ...
      'short');
  
 % Write codes and values for the multi-valued parameters
    
  fwrite(fid_NCAR_output_file, ...
      Output_vector, ...
      'short');

  % close the file

  status = fclose(fid_NCAR_output_file);
  
end

if length(NCAR_output_file_concatenated) > 0  
  
  % Open the concatenated ncar output file, append mode

  [fid_NCAR_output_file, message] = fopen(NCAR_output_file_concatenated,'a');

  KREC	=1101;				   % kind of record (data, character version)
  LTOT  =1+fix((JPAR+19)/20)*2+fix((MPAR+19)/20)*(NROW+1); % number of lines in record

  % Write the prologue

  fprintf(fid_NCAR_output_file, ...
      '%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i%6i\n', ...
      LTOT,KREC,KINST,KINDAT,IBYR,IBDT,IBHM,IBCS, ...
      IEYR,IEDT,IEHM,IECS,LPROL,JPAR,MPAR,NROW);
  
  % Write codes and values for the multi-valued parameters
  
  fprintf(fid_NCAR_output_file, ...
      '%6i%6i%6i%6i%6i%6i%6i%6i\n', ...
      Output_vector);
  
  % close the file
  
  status = fclose(fid_NCAR_output_file);

end

% all done

