function [ gdlat,gdalt,gclat,rkm  ] = convrt( i,gdlat,gdalt,gclat,rkm )
%
%     converted from  subroutine convrt(i,gdlat,gdalt,gclat,rkm)
%
%     jmh - 11/79  ans fortran 66
%
%     convrt converts between geodetic and geocentric coordinates. the
%     reference geoid is that adopted by the iau in 1964. a=6378.16,
%     b=6356.7746, f=1/298.25. the equations for conversion from
%     geocentric to geodetic are from astron. j., vol 66, 1961, p. 15.
%          i=1   geodetic to geocentric
%          i=2   geocentric to geodetic
%        gdlat   geodetic latitude (degrees)
%        gdalt   altitude above geoid (km)
%        gclat   geocentric latitude (degrees)
%        rkm   geocentric radial distance (km)
%
%
      a   = 6378.16d0;
      ab2 =    1.0067397d0;
      ep2 =    0.0067397d0;
      dtr =    0.0174532925199d0;

      if i == 2 

%        .....geocentic to geodetic.....

         rer = rkm/a;
         a2 = ((-1.4127348d-8/rer+.94339131d-8)/rer+.33523288d-2)/rer;
         a4 = (((-1.2545063d-10/rer+.11760996d-9)/rer+.11238084d-4)/rer-.2814244d-5)/rer;
         a6 = ((54.939685d-9/rer-28.301730d-9)/rer+3.5435979d-9)/rer;
         a8 = (((320.d0/rer-252.d0)/rer+64.d0)/rer-5.d0)/rer*.98008304d-12;
         gcl = dtr*gclat;
         ccl = cos(gcl);
         scl = sin(gcl);
         s2cl = 2.d0*scl*ccl;
         c2cl = 2.d0*ccl*ccl - 1.d0;
         s4cl = 2.d0*s2cl*c2cl;
         c4cl = 2.d0*c2cl*c2cl - 1.d0;
         s8cl = 2.d0*s4cl*c4cl;
         s6cl = s2cl*c4cl + c2cl*s4cl;
         dltcl = s2cl*a2 + s4cl*a4 + s6cl*a6 + s8cl*a8;
         gdlat = gclat + dltcl/dtr;
         gdalt = rkm - a/sqrt(1.d0+ep2*scl*scl);
         
      else

%        .....geodetic to geocentric.....

         gdl = dtr*gdlat;
         sinlat = sin(gdl);
         coslat = cos(gdl);
         sl2 = sinlat*sinlat;
         cl2 = ab2*coslat;
         cl2 = cl2*cl2;
         sinbet = sinlat/sqrt(sl2+cl2);
         sb2 = min(sinbet*sinbet,1.d0);
         cosbet = sqrt(1.d0-sb2);
         rgeoid = a/sqrt(1.d0+ep2*sb2);
         x = rgeoid*cosbet + gdalt*coslat;
         y = rgeoid*sinbet + gdalt*sinlat;
         rkm = sqrt(x*x+y*y);
         gclat = atan2(y,x)/dtr;
      end
