function [ fx,fy,fz ] = gdv(gdlat,gclat,fr,ft,fp,fx,fy,fz)
%
%     converted from subroutine gdv(gdlat,gclat,fr,ft,fp,fx,fy,fz)
%    
%     jmh - 11/79  ans fortran 66
%
%     gdv converts a vector field f at geodetic latitude gdlat and
%     geocentric latitude gclat from a geocentric based representation
%     to a geodetic based representation. the geocentric components
%     are fr (radial outward), ft (increasing geocentric colatitude,
%     e.g. southward) and fp (increasing east longitude). the
%     geodetic components are fx (northward, parallel to surface of
%     earth), fy (eastward, parallel to surface of earth) and fz
%     (downward, perpendicular to surface of earth). fr,ft,fp thus
%     correspond to spherical coordinates r,theta,phi, with their
%     origin at the center of the earth. x,y,z are the coordinates
%     customarily used to describe the three components of the
%     geomagnetic field. fp and fy are the same.

      dtr = 0.0174532925199d0;

      gdl = dtr*gdlat;
      sinlat = sin(gdl);
      coslat = cos(gdl);
      t = dtr*(90.d0-gclat);
      ct = cos(t);
      st = sin(t);
      sind = st*sinlat - ct*coslat;
      cosd = ct*sinlat + st*coslat;
      fx = -ft*cosd - fr*sind;
      fy = fp;
      fz = ft*sind - fr*cosd;
