function [pr,glat,glon] = point(sr,slat,slon,az,el,range,pr,glat,glon)
%
%     converted from subroutine point(sr,slat,slon,az,el,range,pr,glat,glon)
%
%     jmh - 1/80  ans fortran 66
%
%     point calculates the position of a point defined by the radar
%     line-of sight vector to that point.
%
%     input parameters
%        sr    - distance of station from center of earth (km)
%        slat  - geocentric latitude of station (deg)
%        slon  - longitude of station (deg)
%        az    - radar azimuth (deg)
%        el    - radar elevation (deg)
%        range - radar range (km)
%
%     output parameters
%        pr    - distance from center of earth of observation point (km)
%        glat  - observation point geocentric latitude (deg)
%        glon  - observation point longitude (deg)
%
%     ...calculate "line-of-sight" station centered cartesian coords...

%     call csconv(rt,rp,rr,range,90.0d0-el,180.0d0-az,2)
      rt=[]; rp=[]; rr=[]; theta=90.0d0-el; phi=180.0d0-az;
      [rt,rp,rr,range,theta,phi] = csconv(rt,rp,rr,range,theta,phi,2);
      
%     ...calculate "line-of-sight" earth centered cartesian coords
%          and "station" earth centered cartesian coords...

%     call vctcnv(r(1),r(2),r(3),s(1),s(2),s(3),rr,rt,rp,sr,90.0d0-slat,slon,2)
      theta = 90.0d0-slat; r=[1,2,3]; s=[1,2,3];
      [ r(1),r(2),r(3),s(1),s(2),s(3),rr,rt,rp,sr,theta,slon ] = vctcnv(r(1),r(2),r(3),s(1),s(2),s(3),rr,rt,rp,sr,theta,slon,2);
      
%     ...calculate "observation-point" earth centered cartesian coords..

%     call vadd(s,r,p)
      p = s + r;

%     ...calculate "observation-point" earth centered spherical coords..
 
%     call csconv(p(1),p(2),p(3),pr,t,glon,1)
      t=[];
      [p(1),p(2),p(3),pr,t,glon] = csconv(p(1),p(2),p(3),pr,t,glon,1);
      glat = 90.0d0 - t;
