function [rfx,rfy,rfz,pfx,pfy,pfz] = rpcart(sr,slat,slon,az,el,range,rfx,rfy,rfz,pfx,pfy,pfz)
%
%     converted from subroutine rpcart(sr,slat,slon,az,el,range,rfx,rfy,rfz,pfx,pfy,pfz)     
%
%     jmh - 11/79  ans fortran 66
%
%     rpcart computes the components (rfx,rfy,rfz) relative to an earth
%     centered cartesian coordinate system of the radar line of sight
%     vector from a radar with coordinates sr (distance from center
%     of earth), slat (geocentric latitude) and slon (longitude). the
%     observation point is specified by az (azimuth), el (elevation) and
%     range (range). the cartesian coordinates of the observation
%     point are returned in (pfx,pfy,pfz).
%        input - sr,slat,slon,az,el,range
%        output - rfx,rfy,rfz,pfx,pfy,pfz
%
      rx=[]; ry=[]; rz=[];

      dtr = 0.0174532925199d0;
      
      rr = sr;
      rtheta = 90.d0 - slat;
      rphi = slon;
      a = dtr*(180.d0-az);
      e = dtr*(90.d0-el);
      ca = cos(a);
      sa = sin(a);
      ce = cos(e);
      se = sin(e);
      rfr = range*ce;
      rft = range*se*ca;
      rfp = range*se*sa;
      [ rfx,rfy,rfz,rx,ry,rz,rfr,rft,rfp,rr,rtheta,rphi ] = vctcnv(rfx,rfy,rfz,rx,ry,rz,rfr,rft,rfp,rr,rtheta,rphi,2);
      pfx = rx + rfx;
      pfy = ry + rfy;
      pfz = rz + rfz;
