function [ fx,fy,fz,x,y,z,fr,ft,fp,r,theta,phi ] = vctcnv(fx,fy,fz,x,y,z,fr,ft,fp,r,theta,phi,imode)
%
%     converted from  subroutine  vctcnv(fx,fy,fz,x,y,z,fr,ft,fp,r,theta,phi,imode)
%
%     jmh - 11/79  ans fortran 66
%
%     vctcnv converts between the cartesian and spherical coordinate
%     representations of a vector field f. (fx,fy,fz) are the
%     components of the field at (x,y,z). (fr,ft,fp) are the
%     components of the field at (r,theta,phi) in the directions of
%     increasing r, increasing theta and increasing phi. if imode=1,
%     (fx,fy,fz,x,y,z) -> (fr,ft,fp,r,theta,phi). if imode=2,
%     (fr,ft,fp,r,theta,phi) -> (fx,fy,fz,x,y,z). theta and phi are
%     in degrees.
%
      dtr   = 0.0174532925199d0;
      rlmin = 1.d-38;
%     ..
%
      if imode == 2
%
         t = dtr*theta;
         p = dtr*phi;
         ct = cos(t);
         st = sin(t);
         cp = cos(p);
         sp = sin(p);
         x = r*st*cp;
         y = r*st*sp;
         z = r*ct;
         fx = st*cp*fr + ct*cp*ft - sp*fp;
         fy = st*sp*fr + ct*sp*ft + cp*fp;
         fz = ct*fr - st*ft;
         
      else

         rho2 = x*x + y*y;
         r = sqrt(rho2+z*z);
         if sign(z) >= 0
            theta = atan2(sqrt(rho2),1.d0*max(abs(z),rlmin));
         else
            theta = atan2(sqrt(rho2),-1.d0*max(abs(z),rlmin));
         end
         if sign(x) >= 0
            phi = atan2(y,1.d0*max(abs(x),rlmin));
         else
            phi = atan2(y,-1.d0*max(abs(x),rlmin));
         end   
         ct = cos(theta);
         st = sin(theta);
         cp = cos(phi);
         sp = sin(phi);
         theta = theta/dtr;
         phi = phi/dtr;
         fr = st*cp*fx + st*sp*fy + ct*fz;
         ft = ct*cp*fx + ct*sp*fy - st*fz;
         fp = -sp*fx + cp*fy;
         
      end
