% 
% GUISDAP v1.65   
%
% Uses UK integration package, requires /esrsw/uk/lib
%
%

% Set up path variables required

path_GUP='/opt/guisdap/';
path_exps='/opt/guisdap/exps/';

path('/opt/guisdap/m165',path);
path('/opt/guisdap/m165gr',path);
path('/opt/guisdap/m165ESR',path);
path('/opt/guisdap/mex152',path);
path('/esrsw/uk/lib',path);
path('/opt/guisdap/local',path);
path('/opt/guisdap/local/SuperDARN',path);

% additional paths for tau0
path('/esrsw/esr0/dsp/rtg',path);
path('/esrsw/esr0/dsp/pp_generic',path);
path('/esrsw/esr0/exp/tau0',path);

start_GUP

% dbstop if error

global source strategy trace_level data_path result_path ...
    analysis_integr codes_selected antenna_selected tau0_128 ...
    tau0_64 tau0_32
global antennaEfficiency calTemp 

path_GUP='/opt/guisdap/';
path_exps='/opt/guisdap/exps/';

% This control file is for the ESR
name_site='L';

disp(sprintf('\n      Data Analysis for gup0 and gup3 experiments'));
disp(sprintf('              UK (NW) integration package\n'));
disp(sprintf('        Graphics windows for the raw data and the'));
disp(sprintf('        analysed profiles will open automatically.'));
disp(sprintf('       When these are not needed they can be closed'));
disp(sprintf('         and will disappear with the next profile.\n'));

% Experiment name
name_expr = 'unknown';     
name_expr = input( 'Experiment name (eg gup3) in quotes: ');

% code selection to analyse
if strcmp(name_expr,'gup0') == 1
  codes_selected = 'lp';
elseif strcmp(name_expr,'gup3') == 1 | strcmp(name_expr,'twobeam0') == 1
  codes_selected = 'unknown';
  codes_selected = input( 'Code to analyse (ac or lp) in quotes: ');
elseif strcmp(name_expr,'tau0') == 1
  codes_selected = 'ac';
else
  disp(sprintf('    Unknown experiment, sorry \n'));
end

% Time interval to analyse in form
%               Year Month Day Hour Min Sec
analysis_start=[1999    04  08  07  00  00];
analysis_end=  [1999    04  08  12  00  00];

disp(['Please enter the times in the form [YYYY MM DD HH MM SS]']);
disp(['    (Remember to include the [ ] brackets!)']);
analysis_start = input( 'Start time: ');
analysis_end   = input( 'End time:   ');

if analysis_start([1]) >= 2000 | ( analysis_start([1]) == 1999 & ...
      analysis_start([2]) == 12 & analysis_start([3]) > 16 ) 
  antenna_selected = input( 'Please specify the required antenna (either 32 or 42): ');
  if antenna_selected == 42
    data_path = sprintf('/data/%s@42m',name_expr);
    antennaEfficiency = 0.685; % 45.2 dBi gain
    calTemp = 148;
  else  
    antenna_selected = 32;
    data_path = sprintf('/data/%s@32m',name_expr);
    antennaEfficiency = 0.633; % 42,5 dBi gain
    calTemp = 220;
  end
else
  antenna_selected = 32;
  data_path = sprintf('/data/%s',name_expr);
  antennaEfficiency = 0.633; % 42,5 dBi gain
  calTemp = 220;
end   

if  strcmp(name_expr,'tau0') == 1 & analysis_start([1]) <  2000
  antenna_selected = 42;
  antennaEfficiency = 0.685; % 45.2 dBi gain
  calTemp = 148;
end

% postintegration strategy defines how many seconds first to skip and 
% integrate.  Zero integration time means integrate to a move of the 
% antenna

% the vectors are used cyclically
analysis_integr=[60];
analysis_skip  =[ 0];  % Optional, assumed to be zero if not specified

disp(['Please enter the required integration time in the form NN seconds,']);
disp(['  use 00 seconds for integration to a change of direction']);
analysis_integr = input( 'Integration time in seconds: ');

% construct result folder name and create if necessary
result_path = sprintf('/data/analysis/%d-%02d-%02d_%s_%s_%d_%dm', ...
     analysis_start([1 2 3]), name_expr, codes_selected, ...
     analysis_integr([1]),antenna_selected);
if ~exist( result_path )
  eval (['!mkdir ',result_path]);
end
disp(['Writing to ', result_path]);  

if strcmp(name_expr,'twobeam0') == 1
  name_expr = 'gup3';
end

% Integration definitions for Nigel Wade's integration

s_time = sprintf('%d/%d/%d %d:%d:%d', analysis_start([3 2 1 4 5 6]));
e_time = sprintf('%d/%d/%d %d:%d:%d', analysis_end([3 2 1 4 5 6]));
dirs   = sprintf('%04d%02d??_??',     analysis_start([1 2]));
i_time = sprintf('%2d:%02d', fix(analysis_integr/60), mod(analysis_integr,60));

%% NB!  The dirs definition will not let integrations continue over month
%%      boundaries!

realtime = input( 'Enter 1 for real time integration:  ');

if realtime == 1
  source = ['source esr day1 {       ' ...
	'start     ' s_time    ';' ...
	'directory ' data_path ';' ...
	'recurse   ' dirs      ';' ...
	'realtime  '           ';' ...
	'site      ' name_site ';' ...
	'}     ' ];
else
  source = ['source esr day1 {       ' ...
	'start     ' s_time    ';' ...
	'directory ' data_path ';' ...
	'recurse   ' dirs      ';' ...
	'site      ' name_site ';' ...
	'}     ' ]; 
end

if analysis_integr([1]) > 0
  % Integration for fixed time
  strategy = ['filter time { ' ...
	'start '  s_time ';' ...
	'end   '  e_time ';}' ...
	'filter power { min 100 kW; } ' ...
	'integrate time { ' ...
	'start         ' s_time  ';' ...
	'period        ' i_time  ';' ...
	'}   '];
else
  % Integration to antenna motion
  strategy = ['filter time { ' ...
	'start '  s_time ';' ...
	'end   '  e_time ';}' ...
	'filter power { min 100 kW; } ' ...
	'integrate move { }' ];
end

% Uncomment the next line for loads of diagnostics from integrate
% trace_level = 3;

if strcmp(name_expr,'gup0') == 1

  % RANGE DEFINITIONS, PICK ONE:
  % The range gate definitions for whole range
  % rangeLP=[102:3:150 150:12:330 330:36:690 690:72:1000];lenLP=length(rangeLP);

  % The range gate definitions for whole range, but ignoring altitudes with
  % only the short pulse data
  rangeLP=[150:12:330 330:36:690 690:72:1000];lenLP=length(rangeLP);
 
  % The range gate definitions for reduced range 
  % rangeLP=[150:12:330 330:36:600];lenLP=length(rangeLP);
 
  % ANALYSIS MODE, PICK ONE:

  % Analyze each pulse separately, combining the two halfs of IPP together
  % analysis_range=[rangeLP rangeLP rangeLP rangeLP];
  % analysis_code=[kron([68 57 24 13],ones(1,lenLP))];

  % Analyse pulses separately, ignoring short pulse
  % analysis_range=[rangeLP rangeLP rangeLP];
  % analysis_code=[kron([57 24 13],ones(1,lenLP))];
  
  % Analyze all pulses together
  analysis_range=[rangeLP];
  analysis_code=[kron([13245768],ones(1,lenLP))];

  % Analyze all pulses together, leaving out the short pulse
  % analysis_range=[rangeLP];
  % analysis_code=[kron([132457],ones(1,lenLP))];

elseif strcmp(name_expr,'gup3') == 1 

  % The range gate definitions for whole range ( long pulse 150 to 215 km is
  % contaminated by clutter so ignore)
  % rangeLP=[150:12:330 330:36:690 690:72:1000];lenLP=length(rangeLP);
  rangeLP=[215:12:330 330:36:690 690:72:1000];lenLP=length(rangeLP);
  rangeAC=[90:3:150 150:6:210 210:12:330 330:36:690];lenAC=length(rangeAC);

  % ANALYSIS MODE, PICK ONE:
  % Long pulse on 1 and 2, alternating code on 3 and 4
  if strcmp(codes_selected,'lp') == 1
    % Analyse long pulse code together only
    analysis_range=[rangeLP];
    analysis_code=[kron([12],ones(1,lenLP))];
  elseif strcmp(codes_selected,'ac') == 1
    % Analyse alternating codes together only
    analysis_range=[rangeAC];
    analysis_code=[kron([34],ones(1,lenAC))];
  else
    disp(sprintf('    Unknown code, sorry \n'));
  end
  
  % Analsze all pulses separately
  % analysis_range=[rangeLP rangeLP rangeAC rangeAC];
  % analysis_code=[kron([1 2],ones(1,lenLP)), kron([3 4],ones(1,lenAC))];

  % Analyse alternating code and long pulse separately
  % this order is better for the plotters!
  % analysis_range=[rangeLP rangeAC];
  % analysis_code=[kron([34],ones(1,lenAC)), kron([12],ones(1,lenLP))];
  
  % Analyze all pulses together
  % rangeLP=[90:3:150 150:6:210 210:12:330 330:36:690 690:72:1000];lenLP=length(rangeLP);
  % analysis_range=[rangeLP];
  % analysis_code=[kron([1324],ones(1,lenLP))];

elseif strcmp(name_expr,'tau0') == 1 

  % initialise the reorganisation of the data for GUISDAP
  disp(sprintf('Initialising for tau0, 12.8 seconds....\n'));  
  tau02gup([],1,'2101');
  tau0_128 = 1; tau0_64 = 0; tau0_32 = 0;
  
  rangeAC=[90:3:150 150:6:204 204:12:330 330:36:1100];lenAC=length(rangeAC);

  analysis_range=[rangeAC];
  analysis_code=[kron([12],ones(1,lenAC))];
  
else
  
  disp(sprintf('    Unknown experiment, sorry \n'));

end

% analysis_control(1) : if error of Ne exceeds this, no fit done
% analysis_control(2) : iteration stopped, when step below this
% analysis_control(3) : max number of iterations
% analysis_control(4) : variance calculation
analysis_control=[.5 .01 100 1];

% display_figures(1) : data dump shown
% display_figures(2) : raw electron density shown
% display_figures(3) : data and fitted curve for each fit shown
% display_figures(4) : results shown after each dump
display_figures=[1 0 0 1];
%display_figures = input( 'Select graphics output in the form [0 0 0 1]: ');

!logger -p local0.info -t Starting GUISDAP 1.65 analysis with UK integration....

NWan_start

exit