% radar_eq.m: radar equation for monostatic and bistatic cases
% GUISDAP v.1.60 96-05-27 Copyright Asko Huuskonen and Markku Lehtinen
% 
% function radar_eq
  function radar_eq

global ch_fradar  ch_gain  ch_Pt ch_az ch_el p_XMITloc p_RECloc antennaEfficiency
global v_lightspeed v_electronradius v_Boltzmann p_dtau p_R0 p_N0 
global ad_coeff ad_range ad_w a_Magic_const
global lpg_h lpg_w lpg_code lpg_bcs lp_vc vc_ch
global ADDR_SHIFT name_site 
global sc_angle sc_R0 sc_R1 ch_range k_radar k_radar0
global name_expr

scale=(p_dtau*1e-6*v_lightspeed/2); % Scale factor from p_dtau units to meters

Cbeam=0.460; % This factor depends on the beam geometry

eff = antennaEfficiency;

% First find the ranges and the scattering angles from the common volume
% For monostatic case quite simply 
% Check that distance from transmitter to receiver less than 100 m
if max(abs(gg2gc(p_XMITloc)-gg2gc(p_RECloc)))<.1
  sc_angle=pi;
  sc_R0=p_R0*scale;
  sc_R1=p_R0*scale;
  k_radar=k_radar0;
  
  % Effective beam cross section
  Aeff=Cbeam*eff*(4*pi*sc_R0^2)./ch_gain;

  % Volume for unit pulse length 
  Veff=Aeff*scale; 
  % Comment: Pulse lengths are also expressed in units of p_dtau
  %    Multiplication by scale is included here so that
  %    is is not needed in functions dirthe and power_prof
else
  ch=1;
  [gg_sp,angle,ranges]=loc2gg(p_RECloc,[ch_el(ch),ch_az(ch),ch_range(ch)],p_XMITloc);
  sc_angle=angle;
  sc_R0=ranges(2)*1E3;
  sc_R1=ranges(1)*1E3;

% Effective scattering volume in m^3 for the remotes
  P=(32*pi/0.3215)^2/3.63;
  Veff=(pi/P)^1.5*(sc_R0^2*sc_R1^2)/sqrt(sc_R0^2+sc_R1^2)/sin(sc_angle);
  fprintf(' Veff is %.4g\n',Veff)
  % Update range variables for the new geometry
   ind=find(lpg_bcs=='s');
   range=sc_R1/scale;
   lpg_h(ind)=range*ones(size(ind));
   lpg_w(ind)=(range/100)*ones(size(ind));
   ad=ADDR_SHIFT+lpg_addr(ind);
   ad_range(ad)=range*ones(size(ad));
   ad_w(ad)=(range/100)*ones(size(ad));
  % Update now the radar k 
  k_radar=k_radar0*sin(sc_angle/2);
end

lambda=v_lightspeed./ch_fradar;

% Single electron cross section at the beam intersection for unit power
polfac=1-0.5*sin(sc_angle)^2;
%fprintf(' Polarization factor is %.2f\n',polfac)
P0perPt=4*pi*(v_electronradius^2)*polfac*...
  (ch_gain./(4*pi*sc_R0^2)).*(ch_gain./(4*pi*sc_R1^2)).*(lambda.^2/(4*pi));
  
% Multiplier for scale electron density and true power

% adjust number of channels for gup3
if ( name_expr == 'gup3' )
  ch_Pt = ch_Pt(1)*ones(1,4);
elseif ( name_expr == 'gup0' )
  ch_Pt = ch_Pt(1)*ones(1,8);  
end

p_coeff0=P0perPt.*ch_Pt.*Veff*p_N0; 
% Calculate now the factor for virtual channels
vc=find(vc_ch>0); % These virtual channels in use
p_coeff0=p_coeff0(vc_ch(vc))./(v_Boltzmann*Ap(vc,0)/(p_dtau*1e-6));

% For monostatic case calculate for each point the range factor
for sig=find(lpg_bcs=='s')
  % Must find the virtual channel now
  lp=lpg_lp(sig);
  vc=lp_vc(lp(1));
  addr=ADDR_SHIFT+lpg_addr(sig);
  ad_coeff(addr)=p_coeff0(vc)*(sc_R1./(scale*ad_range(addr))).^2;
end

% Finally factor to compensate for all the inaccuracies in the numeric constants
ad_coeff=ad_coeff/a_Magic_const;

