function [msg,X] = tau0_xdef(Action,version)

%[MSG,X] = TAU0_XDEF Experiment info for rtg (and analysis).
%
%   ACTION is either 'init' or 'reinit'|'xdef'
%   VERSION is a 3-letter string like '141'. Supported versions are
%
%       100 110 120 130 140 141 150
%       200 202 210 211 220
%
%   See also levelmap.m and levelmap_L???.dat files.
%
% 29-Feb-2000 Jm
% 02-Apr-2000 Jm Version 211 added. Note that the levelmap layout also
%                changed a litle starting from this version, 
%                Version 220 added.
% 29-Nov-2000 TvE This version modified to understand locating
%                 levelmaps for different pre-integration periods


%{----------------------------------------------------------------------

    if nargin < 1 | nargin > 2
        msg = [mfilename ': Wrong number of input arguments'];
    elseif strcmp('init',Action) 
        msg = menudef;
    elseif strcmp('reinit',Action) | strcmp('xdef',Action)        
        if nargin ~= 2
            msg = [mfilename ': Wrong number of input arguments'];
            X = [];
        else
            [X,msg] = xdef(version);
        end            
    else
        msg = [mfilename ': Illegal input parameter (' Action ')'];
    end
%}tau0_xdef

    
function msg = menudef
%-----------------------------------------------------------------------
% Place here tau0 CHANNEL and MODE menu definitions.
%-----------------------------------------------------------------------
%{
    global rtg_CHANNELS rtg_MODES FREQCH MODE

    msg = '';
     
    %------------------
    % define CHANNELS
    %------------------

    rtg_CHANNELS= cell2struct({

        %--------------------------------------
        % NAME             RMB          isLP
        %--------------------------------------
        ' AC1',             1,		 0;
        ' AC2',             2,		 0;
        ' AC 1&2',          [1,2],       0;
        % ------------------------------------
    },{'name','RMB','isLP'},2);

    FREQCH  =  1;

    %---------------
    % define MODES 
    %---------------

    rtg_MODES = cell2struct({
        %-----------------------------------
        % NAME                        ID 
        %-----------------------------------
        ' s0,g0',                      101;
        ' s0',                         3; 
        ' s ',                         2;
        ' x',                          103;
        ' x,y',                        107;
        ' g',                          105;
        ' g,c,systemp',                106;
	' ACF ',                       10;
	' ACF r^2',                    12;
	' SP ',                        11;
 	' SP r^2',                     13;
        '   TX re,im',                 6;
        '   TX pow',                   108;
        '   TX abs',                   7;
        '   TX phase',                 8;
        '   TX/tx0',                   9
        %-----------------------------------
    },{'name','id'},2);

    MODE = 1;	    

    return
%}menudef


function [X,msg] = xdef(version)    
%-----------------------------------------------------
% Initialize version-dependent part of pp_generic/tau0
%
%{
    msg = '';
    levelmaproot = fullfile(rtgget('exproot'),'tau0',filesep);

    %-------------------------------------------------------------------
    % Load levelmap. 
    %-------------------------------------------------------------------

    mapname = [levelmaproot 'levelmap_L' version '.dat'];
    [ok,msg] = levelmap(mapname);
    if ok
        fprintf(1,'\n%s: %s\n',mfilename,msg);
        msg = '';
    else
        return  % error
    end        

    % after loading special level map files, strip of final digit of
    % version mumber
    version = str2num(version);
    version = fix(version/10);
    
    %-----------------------------------------------------------------------
    % Define here those version dependent things that
    % are NOT defined via levelmap
    %-----------------------------------------------------------------------

    X = pp_xdef('new');
    %vsnum = str2num(version);
    vsnum = version;

    if vsnum == 100
        X.guporder  = 0;
        X.snoise    = 0; 
        X.txsamples = 4*15;
        X.Nsamples  = 458;
        X.csamples  = 15;			  
        X.Lagweight = [4/3 2.0 4.0; 4.0 2.0 4/3];
			% first row is weights when decoding from below,
			% second row is weights when decoding from above
        X.ACnbits   = 15;
        X.Nkill     = [0 42];  
        X.gkill     = [0 0];       % clutter subtraction in gaincurve
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 64;  
        X.AClags    = 1:8;
        X.Nfract    = 4;  
        X.Totdecim  = 160; 
        X.Sysconst  = [1 1];
        txon          = [50 1074]; 	
        rxon          = 2368;	       

    elseif vsnum == 110
        X.guporder  = 0;
        X.snoise    = 1; 
        X.txsamples = 4*15;
        X.Nsamples  = 433;
        X.csamples  = 40;			  
        X.Lagweight = 1.0;
        X.ACnbits   = 15;
        X.Nkill     = [0 42];  
        X.gkill     = [0 0];
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 64;  
        X.AClags    = 1:8;	
        X.Nfract    = 4;  
        X.Totdecim  = 160; 
        X.Sysconst  = [1 1];
        txon          = [50 1074]; 
        rxon          = 2368;
	        
    elseif vsnum == 120
        X.guporder  = 0;
        X.snoise    = 0;
        X.txsamples = 2*15;
        X.Nsamples  = 229;
        X.csamples  = 6;
        X.Lagweight = [1.7;1.7];
        X.ACnbits   = 15;	     
        X.Nkill     = [0 21];      
        X.gkill     = [0 0];
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 64;  
        X.AClags    = 1:8;
	X.Nfract    = 2;	     
        X.Totdecim  = 320; 
        X.Sysconst  = [1 1];
        txon          = [50 1074];
        rxon          = 2368;

    elseif vsnum == 130
        X.guporder  = 0;
        X.snoise    = 1;
        X.txsamples = 4*15;
        X.Nsamples  = 458;
        X.csamples  = 15;			  
        X.Lagweight = [4/3 2.0 4.0; 4.0 2.0 4/3];
        X.ACnbits   = 15;
        X.Nkill     = [0 42];  
        X.gkill     = [0 inf];
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 64;  
        X.AClags    = 1:8;	
        X.Nfract    = 4;  
        X.Totdecim  = 160; 
        X.Sysconst  = [1 1];
        txon          = [50 1074]; 	
        rxon          = 2368;
	        
    elseif vsnum == 140
        X.guporder  = 0;
        X.snoise    = 1; 
        X.txsamples = 4*15; 
        X.Nsamples  = 458;
        X.csamples  = 15;			  
        X.Lagweight = [4/3 2.0 4.0; 4.0 2.0 4/3];
        X.ACnbits   = 15;
        X.Nkill     = [0 42];  
        X.gkill     = [0 0]; 
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 64;  
        X.AClags    = 1:8;	
        X.Nfract    = 4;  
        X.Totdecim  = 160; 
        X.Sysconst  = [1 1];
        txon          = [50 1074]; 	
        rxon          = 2368;

    elseif vsnum == 141
        % This version first run 8-Oct-1999, with esrant 2.

        X.guporder  = 0;
        X.snoise    = 1; 
        X.txsamples = 4*15; 
        X.Nsamples  = 458;
        X.csamples  = 15;			  
        X.Lagweight = [4/3 2.0 4.0; 4.0 2.0 4/3];
        X.ACnbits   = 15;
        X.Nkill     = [42 42];    % see Note 1
        X.gkill     = [0 0];      % see Note 2
        X.Ncycles   = 20;         
        X.Rep       = 640000;  
        X.ACbaud    = 64;  
        X.AClags    = 1:8;	
        X.Nfract    = 4;  
        X.Totdecim  = 160; 
        X.Sysconst  = [1 1];
        txon        = [50 1074]; 	
        rxon        = 2368;

        % Note 1. Clutter subtraction accidentially done also on AC1. Not
        %         a so bad thing actually.  
        
        % Note 2. gkill was actually specified as [0 Inf], but due to DSP
        %         programming error, g2 did hot get the normal extra weight 2.

    elseif vsnum == 150
        X.guporder  = 0;
        X.snoise    = 1; 
        X.txsamples = 4*15; 
        X.Nsamples  = 458;
        X.csamples  = 15;			  
        X.Lagweight = [4/3 2.0 4.0; 4.0 2.0 4/3];
        X.ACnbits   = 15;
        X.Nkill     = [30 30];  
        X.gkill     = [inf inf];
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 64;  
        X.AClags    = 1:8;	
        X.Nfract    = 4;  
        X.Totdecim  = 160; 
        X.Sysconst  = [1 1];
        txon          = [50 1074]; 	
        rxon          = 2368;

    elseif vsnum == 200
        % This version first run 15-Nov-1999 as SP-FI

        X.guporder  = 0;
        X.snoise    = 1; 
        X.txsamples = 3*16; 
        X.Nsamples  = 366;
        X.csamples  = 12;			  
        X.Lagweight = [3/2 3; 3 3/2];
        X.ACnbits   = 16;
        X.Nkill     = [10 30];  
        X.gkill     = [0 0];    % 1)
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 60;  
        X.AClags    = 1:8;	
        X.Nfract    = 3;  
        X.Totdecim  = 200; 
        X.Sysconst  = [1 1];
        txon          = [50 1070]; 	
        rxon          = 2364;

        % Note 1. c-kill on gaincurve was done, but not properly weighted.

    elseif vsnum == 201
        X.guporder  = 0;
        X.snoise    = 1; 
        X.txsamples = 3*16; 
        X.Nsamples  = 366;
        X.csamples  = 12;			  
        X.Lagweight = [3/2 3; 3 3/2];
        X.ACnbits   = 16;
        X.Nkill     = [10 30];  
        X.gkill     = [inf inf];    % clutter subtraction in gaincurve
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 60;  
        X.AClags    = 1:8;	
        X.Nfract    = 3;  
        X.Totdecim  = 200; 
        X.Sysconst  = [1 1];
        txon          = [50 1070]; 	
        rxon          = 2364;

    elseif vsnum == 202

        X.guporder  = 0;
        X.snoise    = 1; 
        X.txsamples = 3*16; 
        X.Nsamples  = 366;
        X.csamples  = 12;			  
        X.Lagweight = [3/2 3; 3 3/2];
        X.ACnbits   = 16;
        X.Nkill     = [0 0];  % clutter cancellation [10 30] is done transparently
        X.gkill     = [0 0];  
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 60;  
        X.AClags    = 1:8;	
        X.Nfract    = 3;  
        X.Totdecim  = 200; 
        X.Sysconst  = [1 1];
        txon        = [50 1070]; 	
        rxon        = 2364;

    elseif vsnum == 210

        X.guporder  = 1;      % guisdap conforming number of decoded profiles  
        X.snoise    = 1; 
        X.txsamples = 16*3; 
        X.Nsamples  = 366;
        X.csamples  = 12;			  
        X.Lagweight = [3/2 3; 3 3/2];
        X.ACnbits   = 16;
        X.Nkill     = [0 0];  % clutter cancellation [0 30] is done transparently
        X.gkill     = [0 0];  
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 60;  
        X.AClags    = 1:8;	
        X.Nfract    = 3;  
        X.Totdecim  = 200; 
        X.Sysconst  = [1 1];
        txon        = [50 1070]; 	
        rxon        = 2364;

    elseif vsnum == 211

        X.guporder  = 1;      % guisdap conforming number of decoded profiles  
        X.snoise    = 1; 
        X.txsamples = 16*3; 
        X.Nsamples  = 366;
        X.csamples  = 12;			  
        X.Lagweight = [3/2 3; 3 3/2];
        X.ACnbits   = 16;
        X.Nkill     = [0 0];  % clutter cancellation [0 30] is done transparently
        X.gkill     = [0 0];  
        X.Ncycles   = 10;
        X.Rep       = 640000;  
        X.ACbaud    = 60;  
        X.AClags    = 1:8;	
        X.Nfract    = 3;  
        X.Totdecim  = 200; 
        X.Sysconst  = [1 1];
        txon        = [50 1070]; 	
        rxon        = 2364;

    elseif vsnum == 220

        X.guporder  = 1;      % guisdap conforming number of decoded profiles  
        X.snoise    = 1; 
        X.txsamples = 16*2; 
        X.Nsamples  = 244;
        X.csamples  = 7;			  
        X.Lagweight = [1.7; 1.7];
        X.ACnbits   = 16;
        X.Nkill     = [0 0];  % clutter cancellation [0 20] is done transparently
        X.gkill     = [0 0];  
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 60;  
        X.AClags    = 1:8;	
        X.Nfract    = 2;  
        X.Totdecim  = 300; 
        X.Sysconst  = [1 1];
        txon        = [50 1070]; 	
        rxon        = 2364;

    elseif vsnum == 221

        X.guporder  = 1;      % guisdap conforming number of decoded profiles  
        X.snoise    = 1; 
        X.txsamples = 16*2; 
        X.Nsamples  = 244;
        X.csamples  = 7;			  
        X.Lagweight = [1.7; 1.7];
        X.ACnbits   = 16;
        X.Nkill     = [0 0];  % clutter cancellation [0 20] is done transparently
        X.gkill     = [0 0];  
        X.Ncycles   = 10;
        X.Rep       = 640000;  
        X.ACbaud    = 60;  
        X.AClags    = 1:8;	
        X.Nfract    = 2;  
        X.Totdecim  = 300; 
        X.Sysconst  = [1 1];
        txon        = [50 1070]; 	
        rxon        = 2364;

    elseif vsnum == 230

        X.guporder  = 1;      % guisdap conforming number of decoded profiles  
        X.snoise    = 1; 
        X.txsamples = 16*4; 
        X.Nsamples  = 489;
        X.csamples  = 16;			  
        X.Lagweight = [4/3 2.0 4.0; 4.0 2.0 4/3]; 
        X.ACnbits   = 16;
        X.Nkill     = [0 0];  % clutter cancellation [0 40] is done transparently
        X.gkill     = [0 0];  
        X.Ncycles   = 20;
        X.Rep       = 640000;  
        X.ACbaud    = 60;  
        X.AClags    = 1:8;	
        X.Nfract    = 4;  
        X.Totdecim  = 150; 
        X.Sysconst  = [1 1];
        txon        = [50 1070]; 	
        rxon        = 2364;

    elseif vsnum == 241

        X.guporder  = 1;      % guisdap conforming number of decoded profiles  
        X.snoise    = 1; 
        X.txsamples = 16*3; 
        X.Nsamples  = 273;
        X.csamples  = 9;			  
        X.Lagweight = [3/2 3; 3 3/2]; 
        X.ACnbits   = 16;
        X.Nkill     = [0 0];  % clutter cancellation [0 30] is done transparently
        X.gkill     = [0 0];  
        X.Ncycles   = 10;     % integration period 6.4 s  
        X.Rep       = 640000;  
        X.ACbaud    = 75;  
        X.AClags    = 1:8;	
        X.Nfract    = 3;  
        X.Totdecim  = 250;    % 25 us sampling
        X.Sysconst  = [1 1];
        txon        = [50 1353]; 	
        rxon        = 2859;

    else
        msg = ['Unsupported tau0 version (' version ')' ];
        disp(msg);
        return;
    end        

    X.weight  = [ 1  1 ];

    Fclock  = 10.0e6;       % A/D sampling rate (Hz)    
    X.Fs    = Fclock/X.Totdecim;	  
    X.Tau   = 1/X.Fs;
  	
    %-------------------------------------------------------------------
    % IF frequences. Note that in tau0 experiments, gaincurves are sampled on
    % DIFFERENT freqs (fg) than signal (f). The frequences below should not
    % be trusted, as it is possible to change freqs interactively. For those
    % versions of tau0 runs, where d_parbl already contains frequences, those
    % should be used.
    %-------------------------------------------------------------------

    X.f  = [7.03125 7.50];    % [CH1 CH4]  d_barbl(31,34)
    X.fg = [7.15000 7.35];    % [CH2 CH5]  d_parbl(32,35)

    %-------------------------------------------------------------------
    % Range information
    %-------------------------------------------------------------------
   
    X.r0 = (rxon-txon)*0.150;
    X.dr = X.Tau*1e6*0.150;

    tau = X.Tau*1e6;
    r = ac_profranges(X.ACnbits,X.AClags(end),X.Nfract,tau); % km below r0
    X.profrange{1} = X.r0(1) + r;
    X.profrange{2} = X.r0(2) + r;
 
    %----------------------------------------------------------------------
    % Get the result memory addresses and sizes of the various components
    % of the blocks AC1 and AC2
    %----------------------------------------------------------------------
    
    AC1 = 1; AC2 = 2;    
    if vsnum < 211
        XLAG = 1; SIG = 2; BGR = 3; INJ = 4; TX = 5; SINJ = 6;
    else
        XLAG = 1;  SINJ = 2; SIG = 3; BGR = 4; INJ = 5; TX = 6;
    end            

    [X.ssa(AC1),X.slen(AC1)] = levelmap(AC1,SIG); 
    [X.b1sa(AC1),X.blen(AC1)] = levelmap(AC1,BGR); 
    [X.c1sa(AC1),X.clen(AC1)] = levelmap(AC1,INJ); 
    
    [X.ssa(AC2),X.slen(AC2)] = levelmap(AC2,SIG); 
    [X.b1sa(AC2),X.blen(AC2)] = levelmap(AC2,BGR); 
    [X.c1sa(AC2),X.clen(AC2)] = levelmap(AC2,INJ); 

    if X.snoise
        [X.ysa(AC1),X.ylen(AC1)] = levelmap(AC1,SINJ);
        [X.ysa(AC2),X.ylen(AC2)] = levelmap(AC2,SINJ);
    end

    if X.txsamples
        [X.tsa(AC1),X.tlen(AC1)] = levelmap(AC1,TX);
        [X.tsa(AC2),X.tlen(AC2)] = levelmap(AC2,TX); 
    else
        X.tsa = [];
        X.tlen = zeros(2,1);
    end 

    % Relative start addresses within a RMB, and lengths of signal profiles.
    
    [sa,len] = ac_profmap(X.Nsamples,X.AClags(end),X.Nfract,X.guporder);
    X.profsa{AC1}  = sa;      
    X.proflen{AC1} = len;
    X.profsa{AC2}  = sa;      
    X.proflen{AC2} = len;

    X.pp  = 1:X.Nsamples;
    X.cpp = 1:X.csamples;		       
    X.tpp = 1:X.tlen(1);   

%}xdef


