function [Time,Ran,Alt,Ne,Te,Ti,Vi,Status,name_expr] = load_param(data_path)
% @(#)load_param.m	1.2 98/08/04
% Function to read the plasma parameters from
% GUISDAP result files
% Please specify the data directory in the configuration file config.m
% The data directory must contain GUISDAP MAT-files and a file
% named filelist.dat
%
% The Geographical Latitudes are calculated using Asko Huuskonen's loc2gg.m
% routine from Guisdap v1.60
%
% Philippe Gamet - EISCAT Group 96/07/08
%
% 8/98 Modified to return NCAR convention velocity signs

if ~strcmp(data_path(length(data_path)),'/')
	data_path(length(data_path)+1) = '/';
end;

% generate a filelist for the input directory in memory to avoid cases
% where the filelist.dat is not up to date.  Needs getfilelist.m and
% isdirectory.m in the path; if these are missing, use the following
% two lines instead:
% load([data_path, 'filelist.dat']);
% n = size(filelist);

[filelist,errmsg]= getfilelist(data_path);
n = length(filelist);

n_tot	= n(1)*2;

disp(' ');
disp('Source directory:');
disp(data_path);
	file	= int2str(filelist(1));
	s	= size(file);

        for ipos = s(2):7           % pre-pad filename to 8 characters
            file = ['0' file];   
        end

	eval(['load ',data_path,file]);
	s		= size(r_param);
	n_alt		= s(1);

Ne		= ones(n_alt,n_tot);
Ti		= ones(n_alt,n_tot);
Te		= ones(n_alt,n_tot);
Vi		= zeros(n_alt,n_tot);
Time	= zeros(n_tot,1);
Alt		= zeros(n_alt,n_tot);
Ran		= zeros(n_alt,n_tot);

  for i=1:n_tot/2;
	file	= int2str(filelist(i));
	s	= size(file);

        for ipos = s(2):7           % pre-pad filename to 8 characters
            file = ['0' file];   
        end

	disp(['loading data from file ',file,'.mat (',num2str(i),'/',num2str(n(1)),')']);
	eval(['load ',data_path,file]);

	j = (i-1)*2 + 1;
	Ne(:,j)			=	real(log10(r_param(:,1)));
	Ne(:,j+1)		=	real(log10(r_param(:,1)));
	Ti(:,j)	 		=	r_param(:,2);
	Ti(:,j+1) 		=	r_param(:,2);
	Ti(:,j)	 		=	r_param(:,2);
	Ti(:,j)	 		=	r_param(:,2);
	Ti(:,j+1)		=	r_param(:,2);
	Te(:,j)	 		=	r_param(:,2).*r_param(:,3);
	Te(:,j+1)		=	r_param(:,2).*r_param(:,3);
	
% if the data file contains NCAR velocities, use them, otherwise
% invert the sign of the velocity since the GUISDAp convention is
% opposite to that specified by NCAR

	if exist('r_NCARvel_PosAway')
        	Vi(:,j)	 		=	r_NCARvel_PosAway;
        	Vi(:,j+1)		=	r_NCARvel_PosAway;
	else  
        	Vi(:,j)	 		=	-r_param(:,5);
        	Vi(:,j+1)	 		=	-r_param(:,5);
	      end;
	      
	Alt(:,j) 		= r_h(:,1);
	Alt(:,j+1) 		= r_h(:,1);
	Ran(:,j) 		= r_range(:,1);
	Ran(:,j+1) 		= r_range(:,1);
	Time(j,1)		= toepoch(r_time(1,:));
	Time(j+1,1)		= toepoch(r_time(2,:));
	Status(:,j) 	        = r_status(:,1);
	Status(:,j+1)   	= r_status(:,1);
  end;

disp('Done.');
