function vizu(action)
% Plot GUISDAP results
%
%--------------------------------------------------------------------------
%     EISCAT additions Copyright 1999-2000  EISCAT Scientific Association. 
%     Permission to use, copy, and distribute, for non-commercial purposes, 
%     is hereby granted without fee, provided that this license information 
%     and copyright notice appear in all copies.
%--------------------------------------------------------------------------
% $Header: /net/eiscatl/export/home/tony/matlab/vizu/RCS/vizu.m,v 1.7 2001/02/03 13:55:50 tony Exp $

% To get informations about the data:
% >> vizu('test')
% To open a new graphic window:
% >> vizu('newfig')
% To send the figure to the default greyscale printer:
% >> vizu('print') 
% To reload and plot the data:
% >> vizu('load')
% Note that vizu will automatically reload the data if the source
% directory or the GAP_FILL variable is modified
% To save the current figure in .ps format:
% >> vizu('save')
% To get more selection possibilities
% >> vizu('verbose')

% Original: Philippe Gamet - EISCAT Group, Uppsala, 96/10/07
% Various modifications, etc. TvE
% Extra buttons contributed by Anja Stromme, anja@phys.uit.no, 2001-02
% Works with Matlab 5.2


global Time RAN ALT Ne Te Ti Vi Status name_expr name_ant
global DATA_PATH PLOT_STATUS LOCATION START_TIME END_TIME

disp(['   ']);
disp(['VIZU for Matlab 5.2']);
disp(['   ']);

set(0,'DefaultAxesFontName','default');
set(0,'DefaultAxesFontWeight','default');

set(0,'DefaultTextFontName','default');
set(0,'DefaultTextFontWeight','default');

% Save previous values (if any) and (re)load variables from config file

if ~isempty(PLOT_STATUS)
  OLD_STATUS = PLOT_STATUS;
else
  OLD_STATUS = -99;
end;
if ~isempty(DATA_PATH)
  OLD_PATH = DATA_PATH;
else
  OLD_PATH='none';
  if  ( exist('action')& strcmp(action,'verbose') )
    name_expr = input( 'Experiment name (eg gup3) in quotes: ');
    name_ant  = input( 'Which antenna (32 or 42): ');
    DATA_PATH = input( 'Data path (in quotes please): ');
  else
    disp(['Available data directories in /data/analysis/']);
    eval(['!ls /data/analysis | grep -v ps | grep -v NCAR | grep -v tar']);
    DATA_PATH = input( 'Data directory (in quotes please): ');
    DATA_PATH_YEAR = str2num(DATA_PATH(1:4));
    DATA_PATH_MONTH = str2num(DATA_PATH(6:7));
    DATA_PATH_DAY = str2num(DATA_PATH(9:10));
    name_expr = DATA_PATH(12:15);
    name_ant  = str2num(DATA_PATH(length(DATA_PATH)-2:length(DATA_PATH)-1));
    DATA_PATH = sprintf('/data/analysis/%s', DATA_PATH);
  end;
end;

% Configuration 

%%%%%%%%%%%%%%%% Parameter %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

WHICH_PARAM = 'Ne Te Ti Vi';	% Select parameters to plot

%%%%%%%%%% Time scales %%%%%%%%%%%%%%%%%% (Comment for auto-scale) %%%%

if ~exist('action') | ( exist('action')& ~strcmp(action,'save') )
  if  ( exist('action')& strcmp(action,'verbose') )
    disp(['Please enter the times in the form [YYYY MM DD HH MM SS]']);
    disp(['    (Remember to include the [ ] brackets!)']);
    START_TIME = input( 'Start time: ');
    END_TIME   = input( 'End time:   ');
    MESSAGE1   = input('Type of experiment, eg SP UK, etc., in quotes: '); % Follows experiment name
  else
    START_TIME = [DATA_PATH_YEAR DATA_PATH_MONTH  DATA_PATH_DAY  00  00  00];
    END_TIME   = [DATA_PATH_YEAR DATA_PATH_MONTH DATA_PATH_DAY 24 00 00];
    MESSAGE1   = input('Type of experiment, eg SP UK, etc., in quotes: '); % Follows experiment name
  end;
end;

%%%%%%%%%% Y-Axis scales %%%%%%%%%%%%%%%% (Comment for auto-scale) %%%%

Y_PARAM	= 'Altitude';			% Y-Axis parameter
ALT_SCALE		= [80 600];	% Scale for Altitude (km)
%RAN_SCALE		= [150 900];	% Scale for Range (km)
%LAT_SCALE		= [65 78];	% Scale for Geog. Latitude (deg)

%%%%%%%%%%%%%%%% Plot options %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%GATES	= [1:19 61:81];	% Which gates to plot (Comment to plot all gates)
% Use 'test' option to help decide which gates to plot 

PLOT_STATUS	= 0;
% 0 --> Do not plot if no fit is done OR if the maximum number of 
%       iterations is exceeded (i.e. plot only 'fit ok' data)
% 1 --> Do not plot if no fit is done because data too noisy
%       (i.e. plot 'fit ok' & 'max iter' data)
% 2 --> Plot all data ( status 'ok', 'max iter' or 'no fit')

%%%%%%%%%%%%%%%% Other options %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

TIME_TICKS	= 12; 		% Maximum number of time ticks to print
MESSAGE2	= 'Not for publication - see Rules-of-the-road'; % top
LOCATION	= 'EISCAT Longyearbyen'; % Place where plotting performed
%NE_SCALE 	= [10.2 11.7];	% Scale for Ne (Log10)
NE_SCALE 	= [10.5 12.2];	% Scale for Ne (Log10)
TE_SCALE	= [0 4000];	% Scale for Te (K)
TI_SCALE	= [0 3000];	% Scale for Ti (K)

stretchSecs     = 60;           % Number of seconds to strtch data points

%%%%%%%%%%%%%%% Individual experiment setups %%%%%%%%%%%%%%%%%%%%%%%%%%
if name_expr == 'CP4B'
  WHICH_BEAM = input( 'Which beam (N or W)? ');  
  VI_SCALE		= [-1000 1000];	% Scale for Vi (m/s)
  Y_PARAM	= 'Altitude';			% Y-Axis parameter
  ALT_SCALE		= [250 1100];	% Scale for Altitude (km)
  FIGURE_TITLE	= 'EISCAT VHF RADAR';	% Title for the whole figure
  if WHICH_BEAM == 'N'
    GATES	= [21:40];	% Which gates to plot (Comment to plot all gates)
  else
    GATES	= [1:20];	% Which gates to plot (Comment to plot all gates)
  end
elseif name_expr == 'CP1K'
  VI_SCALE		= [-200 200];	% Scale for Vi (m/s)
  Y_PARAM	= 'Altitude';			% Y-Axis parameter
  ALT_SCALE		= [80 600];	% Scale for Altitude (km)
  FIGURE_TITLE	= 'EISCAT UHF RADAR';	% Title for the whole figure
elseif name_expr == 'gup0'
  %%%%%%%%%% Setup for ESR 32m  %%%%%%%% (Comment for auto-scale) %%%%
  VI_SCALE		= [-200 200];	% Scale for Vi (m/s)
  Y_PARAM	= 'Altitude';			% Y-Axis parameter
  ALT_SCALE		= [150 800];	% Scale for Altitude (km)
  FIGURE_TITLE	= 'EISCAT SVALBARD RADAR';	% Title for the whole figure
elseif name_expr == 'gup3'
  %%%%%%%%%% Setup for ESR 42m  %%%%%%%% (Comment for auto-scale) %%%%
  VI_SCALE		= [-500 500];	% Scale for Vi (m/s)
  Y_PARAM	= 'Altitude';			% Y-Axis parameter
  ALT_SCALE		= [80 600];	% Scale for Altitude (km)
  FIGURE_TITLE	= 'EISCAT SVALBARD RADAR';	% Title for the whole figure
elseif name_expr == 'tau0'  
  Y_PARAM	= 'Altitude';		% Y-Axis parameter
  FIGURE_TITLE	= 'EISCAT SVALBARD RADAR';	% Title for the whole figure
  if name_ant == 32 
    VI_SCALE		= [-500 500];	% Scale for Vi (m/s)
    ALT_SCALE		= [80 600];	% Scale for Altitude (km)
  else
    VI_SCALE		= [-200 200];	% Scale for Vi (m/s)
    ALT_SCALE		= [80 800];	% Scale for Altitude (km)
  end
else  
  VI_SCALE		= [-200 200];	% Scale for Vi (m/s)
  Y_PARAM	= 'Altitude';			% Y-Axis parameter
  ALT_SCALE		= [80 600];	% Scale for Altitude (km)
  FIGURE_TITLE	= 'EISCAT RADAR';	% Title for the whole figure
end   


% Check for missing location entry in config.m

if isempty(LOCATION)
  LOCATION = 'EISCAT';
end;

if ~exist('action') | ( exist('action')& strcmp(action,'verbose') )
  if size(Time) == 0 | ~strcmp(OLD_PATH,DATA_PATH) | OLD_STATUS~=PLOT_STATUS
    [Time,RAN,ALT,Ne,Te,Ti,Vi,Status,name_expr] = load_param(DATA_PATH);
    figure('Position',[400 40 650 800],'Name',['GUISDAP results from ',DATA_PATH]);
    set(gcf,'NumberTitle','off')
    set(gcf,'PaperType','a4');
    
  end;
else
  if strcmp(action,'load')
    [Time,RAN,ALT,Ne,Te,Ti,Vi,Status,name_expr] = load_param(DATA_PATH);
    figure('Position',[400 40 650 800],'Name',['GUISDAP results from ',DATA_PATH]);
    set(gcf,'NumberTitle','off')
  elseif strcmp(action,'newfig')
    figure('Position',[400 40 650 800],'Name',['GUISDAP results from ',DATA_PATH]);
    set(gcf,'NumberTitle','off')
  elseif strcmp(action,'test')
    test(DATA_PATH);
    return;	
  elseif strcmp(action,'print')
    orient tall;
    disp('Sending current figure to default printer ...');
    print
    disp('Done.');
    return;
  elseif strcmp(action,'save')
    set(gcf,'PaperType','a4');
    Start = START_TIME;
    year  = num2str(Start(1:1));
    month = num2str(sprintf('%0.2d',Start(1,2)));
    day   = num2str(sprintf('%0.2d',Start(1,3)));
    name_fig = [year,'-',month,'-',day,'_',name_expr];
    orient tall;
    
    % modify to reduce size of PostScript produced
		
    set(gcf,'RendererMode','manual');
    set(gcf,'Renderer','painters');
    
    disp(['Creating file /tmp/',name_fig,'.ps ...']);
    eval(['print /tmp/',name_fig,' -dpsc2']);
    disp('Adding logo ...')
    eval(['!addlogo.exp ',name_fig,'.ps'])
    eval(['!mv /data/',name_fig,'.ps ', DATA_PATH,'.ps']);
%    eval(['!mv /data/',name_fig,'.ps /data/',name_expr,'@',num2str(name_ant),'m/analysis/',name_fig,'_',num2str(name_ant),'m.ps']);
%    disp(['Done, result in /data/',name_expr,'@',num2str(name_ant),'m/analysis/',name_fig,'_',num2str(name_ant),'m.ps']);
    disp(['Done, result in ', DATA_PATH,'.ps']);
    disp('Done.')
    return;
  end;
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
option = zeros(4,1);
for i=1:length(WHICH_PARAM)-1
  str = [WHICH_PARAM(i),WHICH_PARAM(i+1)];
  if strcmp(str,'Ne')
    option(1) = 1;
  elseif strcmp(str,'Te')
    option(2)	=	1;
  elseif strcmp(str,'Ti')
    option(3)	=	1;
  elseif strcmp(str,'Vi')
    option(4)	=	1;
  end;
end;
n_tot = nnz(option(1:4));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% to label plot to match window selected
Start = START_TIME;
End   = END_TIME;

year = num2str(Start(1:1));
month_ix =['  January February    March    April      May     June',...
	   '     July   AugustSeptember  October November December'];
month = month_ix(9*Start(1,2)-8:9*Start(1,2));
if Start(1,3) == End(1,3)
  day   = num2str(sprintf('%0.2d',Start(1,3)));
else
  day   = [num2str(sprintf('%0.2d',Start(1,3))),'-',num2str(sprintf('%0.2d',End(1,3)))];
end;
t2 = [MESSAGE1,', ',num2str(name_ant),'m, ',name_expr,', ',month,' ',day,', ',year];
t1 = ['Produced at ',LOCATION,', ',date];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ti = subplot(n_tot+1,1,1);
%set(ti,'Position',[0 0.92 0.95 0.08]);
set(ti,'Position',[0.0 0.87 0.95 0.08]);
set(ti,'Visible','off');
text('Position',[0.55,0.85],'HorizontalAlignment','center', ...
    'VerticalAlignment','top', ...
    'String',FIGURE_TITLE,'FontSize',16,'FontWeight','bold');
if ~strcmp(t1,'auto')
  text('Position',[0.55,0.5],'HorizontalAlignment','center', ...
      'VerticalAlignment','top', ...
      'String',t2,'FontSize',10);
end;
text('Position',[0.1,0.15],'HorizontalAlignment','left', ...
    'VerticalAlignment','top', ...
    'String',t1,'FontSize',7);
text('Position',[0.92,0.15],'HorizontalAlignment','right', ...
    'VerticalAlignment','top', ...
    'String',MESSAGE2,'FontSize',7);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Determine the Y-Axis parameter

if upper(Y_PARAM(1)) == 'R'
  Y = 'RAN';
  YTitle = 'RAN (km)';
elseif upper(Y_PARAM(1)) == 'M'
  Y = 'GML';
  YTitle = 'Geomag. lat.';
  g = [73.60086 73.52204 73.44751 73.36974 73.29306 ...
       73.21563 73.13813 73.06375 72.98671 72.91084 ...
       72.84470 72.70182 72.47776 72.25554 72.03100 ...
       71.81182 71.59326 71.37448 71.15875 70.94426 ...
       70.72778 70.42110 70.02116 69.66894];
  GML=repmat(g,1,910);
else
  Y = 'ALT';
  YTitle = 'Altitude (km)';
end;

%if ~exist('GATES')
  GATES = [1:length(ALT(:,1))];
%end;

y_param = eval(Y);
add_plot = 0;
height = (0.80 - (n_tot-1)*0.03)/n_tot;
colormap('jet');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot Ne

if option(1)
  add_plot = add_plot+1;
  axeNe = subplot(n_tot+1,1,add_plot+1);
  set(axeNe,'Position',[0.12 0.06+(n_tot-add_plot)*(height+0.03) 0.8 height]);
  set(axeNe,'FontSize',8);
  set(axeNe,'Box','on');
  grid on;
  
  s=size(Status);
  
  if OLD_STATUS ~= PLOT_STATUS
    for i=1:s(1)
      for j=1:s(2)
	if Status(i,j) > PLOT_STATUS
	  Ne(i,j) = nan;
	end;
      end;
    end;
  end;

  for i=1:s(2)/2
    j = (i-1)*2 + 1;
    Time(j+1)=  Time(j+1) + stretchSecs;
    hndl = surface(Time(j:j+1),y_param(GATES,j:j+1),Ne(GATES,j:j+1));
    set(hndl,'EdgeColor','none');
  end;
  
  if exist('NE_SCALE')
    set(gca,'CLim',NE_SCALE);
  end;
  if (exist('START_TIME') & exist('END_TIME'))
    set(gca,'XLim',[toepoch(START_TIME) toepoch(END_TIME)]);
  end;
  if exist([Y,'_SCALE'])
    set(gca,'YLim',eval([Y,'_SCALE']));
  end;		
  x2time(gca,TIME_TICKS);
  if add_plot == n_tot
    xlabel('UNIVERSAL TIME');
  end;
  ylabel(YTitle);
  my_colorbar;
  text('String','Electron Density (Log10)','Units','Normalized','Position',[1.16 0.5],...
    'HorizontalAlignment','Center','Rotation',-90,'FontSize',8);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot Te

if option(2)
  add_plot = add_plot+1;
  axeTe = subplot(n_tot+1,1,add_plot+1);
  set(axeTe,'Position',[0.12 0.06+(n_tot-add_plot)*(height+0.03) 0.8 height]);
  set(axeTe,'FontSize',8);
  set(axeTe,'Box','on');
  grid on;
           
  s = size(Status); 
	
  if OLD_STATUS ~= PLOT_STATUS
    for i=1:s(1)
      for j=1:s(2)
	if Status(i,j) > PLOT_STATUS
	  Te(i,j) = nan;
	end;
      end;
    end;
  end;
  
  for i=1:s(2)/2
    j = (i-1)*2 + 1;
    hndl = surface(Time(j:j+1),y_param(GATES,j:j+1),Te(GATES,j:j+1));
    set(hndl,'EdgeColor','none');
  end;
  
  if exist('TE_SCALE')
    set(gca,'CLim',TE_SCALE);
  end;
  if (exist('START_TIME') & exist('END_TIME'))
    set(gca,'XLim',[toepoch(START_TIME) toepoch(END_TIME)]);
  end;
  if exist([Y,'_SCALE'])
    set(gca,'YLim',eval([Y,'_SCALE']));
  end;		
  x2time(gca,TIME_TICKS);
  if add_plot == n_tot
    xlabel('UNIVERSAL TIME');
  end;
  ylabel(YTitle);
  my_colorbar;
  text('String','Electron Temperature (K)','Units','Normalized','Position',[1.16 0.5],...
      'HorizontalAlignment','Center','Rotation',-90,'FontSize',8);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot Ti

if option(3)
  add_plot = add_plot+1;
  axeTi = subplot(n_tot+1,1,add_plot+1);
  set(axeTi,'Position',[0.12 0.06+(n_tot-add_plot)*(height+0.03) 0.8 height]);
  set(axeTi,'FontSize',8);
  set(axeTi,'Box','on');
  grid on;
           
  s = size(Status);
  
  if OLD_STATUS ~= PLOT_STATUS
    for i=1:s(1)
      for j=1:s(2)
	if Status(i,j) > PLOT_STATUS
	  Ti(i,j) = nan;
	end;
      end;
    end;
  end;
  
  for i=1:s(2)/2
    j = (i-1)*2 + 1;
    hndl = surface(Time(j:j+1),y_param(GATES,j:j+1),Ti(GATES,j:j+1));
    set(hndl,'EdgeColor','none');
  end;
  
  if exist('TI_SCALE')
    set(gca,'CLim',TI_SCALE);
  end;
  if (exist('START_TIME') & exist('END_TIME'))
    set(gca,'XLim',[toepoch(START_TIME) toepoch(END_TIME)]);
  end;
  if exist([Y,'_SCALE'])
    set(gca,'YLim',eval([Y,'_SCALE']));
  end;		
  x2time(gca,TIME_TICKS);
  if add_plot == n_tot
    xlabel('UNIVERSAL TIME');
  end;
  ylabel(YTitle);
  my_colorbar;
  text('String','Ion Temperature (K)','Units','Normalized','Position',[1.16 0.5],...
      'HorizontalAlignment','Center','Rotation',-90,'FontSize',8);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot Vi

if option(4)
  add_plot = add_plot+1;
  axeVi = subplot(n_tot+1,1,add_plot+1);
  set(axeVi,'Position',[0.12 0.06+(n_tot-add_plot)*(height+0.03) 0.8 height]);
  set(axeVi,'FontSize',8);
  set(axeVi,'Box','on');
  grid on;
  
  s = size(Status);
  
  if OLD_STATUS ~= PLOT_STATUS
    for i=1:s(1)
      for j=1:s(2)
	if Status(i,j) > PLOT_STATUS
	  Vi(i,j) = nan;
	end;
      end;
    end;
  end;
  
  for i=1:s(2)/2
    j = (i-1)*2 + 1;
    if VI_SCALE(1) < VI_SCALE(2)
      hndl = surface(Time(j:j+1),y_param(GATES,j:j+1),Vi(GATES,j:j+1));
    else
      hndl = surface(Time(j:j+1),y_param(GATES,j:j+1),-Vi(GATES,j:j+1));
    end;
    set(hndl,'EdgeColor','none');
  end;
  
  if exist('VI_SCALE')
    if VI_SCALE(1) < VI_SCALE(2)
      set(gca,'CLim',VI_SCALE);
    else
      set(gca,'CLim',-VI_SCALE);
    end;
  end;
  if (exist('START_TIME') & exist('END_TIME'))
    set(gca,'XLim',[toepoch(START_TIME) toepoch(END_TIME)]);
  end;
  if exist([Y,'_SCALE'])
    set(gca,'YLim',eval([Y,'_SCALE']));
  end;		
  x2time(gca,TIME_TICKS);
  if add_plot == n_tot
    xlabel('UNIVERSAL TIME');
  end;
  ylabel(YTitle);
  my_colorbar;
  text('String','Ion Velocity (m/s)','Units','Normalized','Position',[1.16 0.5],...
      'HorizontalAlignment','Center','Rotation',-90,'FontSize',8);
  if VI_SCALE(1) < VI_SCALE(2)
    text('String','(positive away)','Units','Normalized','Position',[1.14 0.5],...
	'HorizontalAlignment','Center','Rotation',-90,'FontSize',8);
  else
    text('String','(positive towards)','Units','Normalized','Position',[1.14 0.5],...
	'HorizontalAlignment','Center','Rotation',-90,'FontSize',8);
  end;
end;

% Add some extra buttons to the graphics window
menu1=uimenu('label', 'Update', 'callback', 'close all, clear all, vizu' );
menu2=uimenu('label', 'Update/Edit', 'callback', 'close all, clear all, vizu(''verbose'')' );
menu3=uimenu('label', 'Save', 'callback','vizu(''save'')');
menu4=uimenu('label', 'Print', 'callback', 'vizu(''print'')');
return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%