function [ cx,cy,cz ] = dircos( sgdlat,slon,sgdalt,az,el,range )
%
%     Returns the direction cosines fx,fy,fzc for an observation
%     at azimuth az, elevation el nd range range from a staion
%     at geodetic latitude sgdlat, longitude slon and altitude
%     sgdalt
%
    
% convert station coordinates from geodetic to geocentric
      gclat = []; rkm = [];
      [ sgdlat,sgdalt,gclat,rkm  ] = convrt( 1,sgdlat,sgdalt,gclat,rkm );
      
% Compute geocentric coordinates at specified point
      pr=[]; pgclat=[]; plon=[];
      [pr,pgclat,plon] = point(rkm,gclat,slon,az,el,range,pr,pgclat,plon);
      
% Convert observation point coordinates from geocentric to geodetic
      plat=[]; palt=[];
      [ plat,palt,glat,pr  ] = convrt( 2,plat,palt,pgclat,pr );
      
% Convert radar propagation vector and observation point position to
% Earth centered Cartesian co-ordinates
      rfx=[]; rfy=[]; rfz=[]; pfx=[]; pfy=[]; pfz=[];
      [rfx,rfy,rfz,pfx,pfy,pfz] = rpcart(rkm,gclat,slon,az,el,range,rfx,rfy,rfz,pfx,pfy,pfz);
      
% calculate direction cosines of radar beam with respect to
% geocentric south, east, up
     rfr=[]; rft=[]; rfp=[]; rr=[]; rt=[]; rp=[];       
     [ rfx,rfy,rfz,pfx,pfy,pfz,rfr,rft,rfp,rr,rt,rp ] = vctcnv(rfx,rfy,rfz,pfx,pfy,pfz,rfr,rft,rfp,rr,rt,rp,1);
     
     cst = rft/range;
     csp = rft/range;
     csr = rfr/range;
     
% Compute geodetic direction cosines.  The direction cosines
% are with respect to x (North), y (East) and z (down).
    cx=[]; cy=[]; cz=[];
    [ cx,cy,cz ] = gdv(plat,pgclat,csr,cst,csp,cx,cy,cz);