% analysisconfigure.m
% mainland analysis for GUISDAP v1.65   
%
% 06-Feb-2001 bi  updated for new system
% 06-Apr-2001 Jm  tau - experiment info updated
% 06-Apr-2001 TvE much modified to match style and conventions at ESR
% 04-Nov-2001 bi  reorganized and updated


% =========================================================================
% CONFIGURE THE ANALYSIS FOR ALL SUPPORTED EXPERIMENTS
% =========================================================================

% ac = alternating code
% lp = long pulse
% pp = power profile (= short pulse)


if strcmp(name_pulse,'cp1lt')
  
% ac combined with lp (various versions)
  codes_selected = 'aclp';
  
  range1 = [90:3.15:121.5];         % gate-by-gate below 121.5
  range2 = [121.5:6.3:171.5];       % two gates below 171.5
  range3 = [171.5:12.6:196.7];      % four gates below 196.7 to try to fit better
  range4 = [196.7:22.5:700];        % matched to lp above 196.7
  analysis_range = [range1 range2 range3 range4];
  code1 = 12*ones(size(range1));    % use 1 (ac) and 2 (pp) below 121.5 km
  code2 = 12*ones(size(range2));    % use 1 (ac) and 2 (pp) below 171.5 km
  code3 = 12*ones(size(range3));    % use 1 (ac) and 2 (pp) below 196.7 km
  code4 = 3*ones(size(range4));     % use 3 (lp) above 196.7 km
  analysis_code = [code1 code2 code3 code4];
  
  range1 = [90:3.15:121.5];         code1 = 12*ones(size(range1));    % use 1 (ac) and 2 (pp)
  range2 = [121.5:6.3:171.5];       code2 = 12*ones(size(range2));    % 
  range3 = [171.5:12.6:247.1];      code3 = 12*ones(size(range3));    %
  range4 = [196.7:22.5:700];        code4 = 3*ones(size(range4));     % use 3 (lp)
  analysis_range = [range1 range2 range3 range4];
  analysis_code = [code1 code2 code3 code4];
  
  range1 = [90:3.15:121.5];         code1 = 12*ones(size(range1));    % use 1 (ac) and 2 (pp)
  range2 = [121.5:6.3:171.5];       code2 = 12*ones(size(range2));    % 
  range3 = [171.5:12.6:247.1];      code3 = 12*ones(size(range3));    %
  range4 = [247.1:25.2:347.9];      code4 = 12*ones(size(range4));    %
  range5 = [347.9:25.2:700];        code5 = 3*ones(size(range5));     % use 3 (lp)
  analysis_range = [range1 range2 range3 range4 range5];
  analysis_code = [code1 code2 code3 code4 code5];

% ac only
  codes_selected = 'ac';

  range1=[90:3.15:121.5];
  range2=[121.5:6.3:171.5];
  range3=[171.5:12.6:350.0];
  analysis_range = [range1 range2 range3];
  code1=12*ones(size(range1));
  code2=12*ones(size(range2));
  code3=12*ones(size(range3));
  analysis_code = [code1 code2 code3];

  range1 = [90:3.15:121.5];         code1 = 12*ones(size(range1));    % use 1 (ac) and 2 (pp)
  range2 = [121.5:6.3:171.5];       code2 = 12*ones(size(range2));    % 
  range3 = [171.5:12.6:247.1];      code3 = 12*ones(size(range3));    %
  range4 = [247.1:25.2:347.9];      code4 = 12*ones(size(range4));    %
  analysis_range = [range1 range2 range3 range4];
  analysis_code = [code1 code2 code3 code4];


% lp only (as per Ian McCrea)
  codes_selected = 'lp';

  range1=[150.0:22.5:800.0];
  analysis_range = [range1];
  code1=3*ones(size(range1));
  analysis_code = [code1];

% analysis_altit = [90 700];
% analysis_classic = 1;
 
  fprintf('analysisconfigure: cp1lt: code is %s\n',codes_selected)


elseif strcmp(name_pulse,'cp4bv')
   
  codes_selected = 'lp';
  
  rangeLP = [300:36:700 700:72:1000 1000:150:1450 1450:250:2450]; 
  rangeLP = [300:72:1450 1450:144:2450]; 
  analysis_range = [rangeLP];
  analysis_code=[kron([1],ones(1,length(rangeLP)))];
  
% group 1:     long pulses combined from virtual channels  1  2
% group 2:  power profiles combined from virtual channels  3  4
  

elseif strcmp(name_pulse,'cp7hv')
   
  codes_selected = 'lp';
  
  rangeLP = [80:36:700 700:72:1000 1000:150:1450 1450:250:2450]; 
  analysis_range = [rangeLP];
  analysis_code=[kron([1],ones(1,length(rangeLP)))];

% disp([name_pulse,': cp7hv not yet implemented: stop.']);
% dbstop


elseif ...
  strcmp(name_pulse,'tau1') | ...
  strcmp(name_pulse,'tau1v') | ...
  strcmp(name_pulse,'tau1av') | ...
  strcmp(name_pulse,'tau1_singel_v') | ...
  strcmp(name_pulse,'tau1avsingle')
  
  codes_selected = 'ac'; 
  dr = 24.0 * 0.15; % 24 us sampling
  
  range1 = 2*[90:dr:121.6];
  range2 = 2*[121.6:(2*dr):172.8];
  range3 = 2*[172.8:(4*dr):198.0];
  range4 = 2*[198.0:(8*dr):700.0];
  range5 = 2*[700.0:(16*dr):1000];
  
  analysis_range = [range1 range2 range3 range4 range5];
  
  code1=1*ones(size(range1));
  code2=1*ones(size(range2));
  code3=1*ones(size(range3));
  code4=1*ones(size(range4));
  code5=1*ones(size(range5));
  
  analysis_code = [code1 code2 code3 code4 code5];


elseif ...
  strcmp(name_pulse,'tau2t') | ...
  strcmp(name_pulse,'tau2at')
  
  global version_expr
  version_expr   = '1.00'; % used in frontend/newsystem.m
  
  codes_selected = 'ac';
  
% the boundaries are from Ian McCrea's cp1lt and we try to approximate his range step also
  
  range1 = [ 90.0:3.6:122.4];
  range2 = [122.4:7.2:172.8];
  range3 = [172.8:12.6:198.0];
  range4 = [198.0:21.6:700.0];
  
  analysis_range = [range1 range2 range3 range4];
  
  code1=1*ones(size(range1));
  code2=1*ones(size(range2));
  code3=1*ones(size(range3));
  code4=1*ones(size(range4));
  
  analysis_code = [code1 code2 code3 code4];
  

else
  
  disp([name_pulse,': unknown code type: stop!']);
  dbstop

  
end

% =========================================================================
 
