% analysissetup.m
% mainland analysis for GUISDAP v1.65   
% Nov 2001: EISCAT update v1.70
%
% 20010206 bi  updated for new system
% 20010406 Jm  tau - experiment info updated
% 20010406 TvE much modified to match style and conventions at ESR
% 20010610 TvE modified for new file name convention
% 20010611 bi  backward-compatible with VHF file names
% 20010611 bi  select data file location
% 20011002 bi  move to /opt/eiscat/apps/guisdap
% 20011007 bi  move to /opt/eiscat/apps/guisdap165
% 20011111 bi  add startup options: keyboard, commonrt, or batch input file
% 20011119 bi  rename to guisdap170 for EISCAT

% append to standard path
  path('/opt/eiscat/apps/guisdap170/m165',path);
  path('/opt/eiscat/apps/guisdap170/m165gr',path);
  path('/opt/eiscat/apps/guisdap170/m165KST',path);
  path('/opt/eiscat/apps/guisdap170/mex152',path);
  path('/opt/eiscat/apps/guisdap170/uklib',path);
  path('/opt/eiscat/apps/guisdap170/Tromso',path);
  path('/opt/eiscat/apps/guisdap170/Tromso/main',path);
  path('/opt/eiscat/apps/guisdap170/Tromso/frontend',path);
  path('/opt/eiscat/apps/guisdap170/Tromso/frontend/newsystem_2gup',path);
  path('/opt/eiscat/apps/guisdap170/SuperDARN',path);

% define path variables for Guisdap
  path_GUP='/opt/eiscat/apps/guisdap170/';
  path_exps='/opt/eiscat/apps/guisdap170/exps/';

% stop on error
  dbstop if error

% execute Guisdap startup script
  start_GUP

% define path variables for Guisdap [again? because of start_GUP?]
  path_GUP='/opt/eiscat/apps/guisdap170/';
  path_exps='/opt/eiscat/apps/guisdap170/exps/';

% globals
  global source strategy trace_level data_path result_path
  global analysis_integr codes_selected antenna_selected
  global antennaEfficiency calTemp vhf_beam

% greeting message
  disp(sprintf(' '));
  disp(sprintf('        Guisdap 1.70 analysis for EISCAT experiments. '));
  disp(sprintf('        Incorporates the 2001 file naming convention. '));
  disp(sprintf(' '));

% default parameters
  if strcmp(analysis_input,'keyboard')
    keyboard = 1;
    analysis_keyboard_inputs
  elseif strcmp(analysis_input,'commonrt')
    keyboard = 0;
    analysis_commonrt_inputs
% elseif strcmp(analysis_input,'batch')
  else
    keyboard = 0;
  % disp(sprintf('analysissetup: batch inputs directory %s',analysis_batch_path));
    disp(sprintf('analysissetup: executing batch input file %s',analysis_input));
  % execute specified file
    eval([analysis_input]);
  end

  if keyboard

    disp(sprintf('        Initialized for the following programs (or for '));
    disp(sprintf('        any program with the same pulse code; the pulse '));
    disp(sprintf('        code is the string before the first _ or the @): '));
    disp(sprintf(' '));
    disp(sprintf('          UHF '));
    disp(sprintf('                      cp1lt@uhf '));
  % disp(sprintf('                      tau2t@uhf '));
  % disp(sprintf('                 tau2at_cp1@uhf '));
    disp(sprintf(' '));
    disp(sprintf('          VHF '));
    disp(sprintf('                      cp4bv@vhf[1|2] '));
    disp(sprintf('                      cp7hv@vhf[0] '));
    disp(sprintf('                       tau1@vhf[1|2] '));
    disp(sprintf('                      tau1v@vhf[1|2] '));
    disp(sprintf('                     tau1av@vhf[1|2] '));
    disp(sprintf('               tau1avsingle@vhf[0] '));
    disp(sprintf('              tau1_singel_v@vhf[0]   (non-2001-convention name)'));
    disp(sprintf(' '));
  % disp(sprintf('          ESR '));
  % disp(sprintf('                       gup0@[32|42]m '));
  % disp(sprintf('                       gup1@[32|42]m '));
  % disp(sprintf('                       gup2@[32|42]m '));
  % disp(sprintf('                       gup3@[32|42]m '));
  % disp(sprintf('                       tau0@[32|42]m '));
  % disp(sprintf(' '));
    disp(sprintf('        Raw data files ending in @vhf include data from the whole antenna '));
    disp(sprintf('        or from both beams if programmed in dual-receiver mode. '));
  % disp(sprintf('        Raw data files ending in @vhf may include both VHF beams. '));
  % disp(sprintf('        This format was used with the 2000 Tromso hardware system '));
  % disp(sprintf('        before the adoption of the 2001 file naming convention. '));
    disp(sprintf(' '));
    disp(sprintf('        Processed VHF data files *@vhf0/1/2 include beams as follows: '));
    disp(sprintf('                  @vhf0 = full antenna (normally boresight)'));
    disp(sprintf('                  @vhf1 = beam 1 (cp4 pointing = boresight from western panels)'));
    disp(sprintf('                  @vhf2 = beam 2 (cp4 pointing = 15 degrees west from eastern panels) '));
  % 
  % Note on VHF pointing:
  %
  % The azimuth of the VHF beams is set in the *2gup.m files, which are called from newsystem.m.
  %
  % The elevation of the VHF beams is set in Tromso/frontend/newsystem_pointing.m, 
  % which is also called from newsystem.m.
  %
  % Calling sequence for *2gup.m and newsystem_pointing.m:
  %   from newsystem.m
  %   from frontend.m
  %   from analysismain_NW.m (after decodeparblock.m and before radar_eq.m)
  %   from analysissetup.m
  %
  % Comments on the VHF beam numbering convention:
  % 
  % From: jussi <jussi.markkanen@sgo.fi>
  % Date: Fri, 25 May 2001 18:13:29 +0300
  % Subject: Re: Tau1 analysis
  % 
  % As I have documented in
  % 
  % http://eiscat.sgo.fi/docs/exp/tau1/tau1desc.html
  % 
  % my intention has been that the data block 1 in the dump should belong to the beam that points
  % directly to geographic north (the left-hand side of the antenna).  I did not know that people
  % have been numbering the beams the other way round.
  % 
  % Anyway, that was the intention.  What actually happens of course depends on how the cables 
  % really are connected, and there are unpleasantly many places where they can be crossed, 
  % last one being the A/D inputs.  I think I made some effort last Autumn to make sure that I knew 
  % which data was which (there was receiver fault in one of the vhf signals paths, so we a rather 
  % good signature availabe), but things _might_ have changed since.
  % 
  % We should find some way to calibrate the beam side in routine manner.
  % 
  % And, yes, the "left-hand side" is the side that is further away from the site building
  % (the western side).  And, yes, too, the A/D input is _not_ the last place where the cables
  % can be crossed, they can actually be (in effect) "crossed" when the R/C selects the A/D
  % converter for the channels, and this selections has been somewhat problematic at some point
  % in time, don't (sigh).
  % 
    disp(sprintf(' '));
    disp(sprintf('        Graphics windows for the raw data and the '));
    disp(sprintf('        analysed profiles will open automatically. '));
    disp(sprintf('        When these are not needed they can be closed '));
    disp(sprintf('        and will disappear with the next profile. '));
  
  % experiment name
    disp(sprintf(' '));
    expnamedone = 'n';
    while ~strcmp(expnamedone(1:1),'y') % loop until answer confimed
      name_expr = input( 'Experiment name (exp@ant) in single quotes: ');
      expnamedone = input(sprintf('Experiment name %s selected (y or n in single quotes): ',name_expr));
      % disp('Experiment name %s selected...',name_expr);
      % expnamedone = input('Selected name okay (y or n in single quotes): ');
    end

  end % keyboard
  disp(sprintf(' '));

% check for bad vhf program+beam combinations
  if ...
    strcmp(name_expr,'cp4bv@vhf0') | ...
    strcmp(name_expr,'cp7hv@vhf1') | ...
    strcmp(name_expr,'cp7hv@vhf2') | ...
    strcmp(name_expr,'tau1@vhf0') | ...
    strcmp(name_expr,'tau1v@vhf0') | ...
    strcmp(name_expr,'tau1av@vhf0') | ...
    strcmp(name_expr,'tau1avsingle@vhf1') | ...
    strcmp(name_expr,'tau1avsingle@vhf2') | ...
    strcmp(name_expr,'tau1_singel_v@vhf1') | ...
    strcmp(name_expr,'tau1_singel_v@vhf2')
    disp(sprintf('analysissetup: YOU BAD! (starting over is suggested...)'));
    exit
  end

% select naming convention
  if keyboard disp(sprintf(' ')); end
  if ...
    strcmp(name_expr,'tau1_singel_v@vhf') | ...
    strcmp(name_expr,'tau1_singel_v@vhf0')
    newnames = 'n';
    disp(sprintf('analysissetup: using old (pre-2001) naming convention'));
  else
    newnames = 'y';
    disp(sprintf('analysissetup: using 2001 naming convention'));
  end

% disp(sprintf(' '));
% newnamesdone = 'n';
% while ~strcmp(newnamesdone(1:1),'y') % loop until answer confimed
%   newnames = input('Use 2001 naming convention (y or n in single quotes): ');
%   if strcmp(newnames(1:1),'y')
%     newnamesdone = input('2001 naming convention selected (y or n in single quotes): ');
%   else
%     newnamesdone = input('2001 naming convention not selected (y or n in single quotes): ');
%   end
% end

% unscramble names

% vhf raw data may have either single or double beam data in one file (@vhf)
% which beam to analyze may be indicated by @vhf1 or @vhf2
% for single beam programs, @vhf and @vhf0 have identical meaning
% processed vhf data will have either one (@vhf1 or @vhf2) or full beam (@vhf0) per file

  if strcmp(name_expr(length(name_expr)-2:length(name_expr)-0),'uhf')
    name_antenna_raw = 'uhf';
    name_radprog = name_expr(1:length(name_expr)-4);
  elseif strcmp(name_expr(length(name_expr)-2:length(name_expr)-0),'32m')
    name_antenna_raw = '32m';
    name_radprog = name_expr(1:length(name_expr)-4);
  elseif strcmp(name_expr(length(name_expr)-2:length(name_expr)-0),'42m')
    name_antenna_raw = '42m';
    name_radprog = name_expr(1:length(name_expr)-4);
  elseif strcmp(name_expr(length(name_expr)-2:length(name_expr)-0),'vhf')
    name_antenna_raw = 'vhf'; % this is used as a flag for the vhf system
    name_radprog = name_expr(1:length(name_expr)-4);
  elseif strcmp(name_expr(length(name_expr)-3:length(name_expr)-1),'vhf')
    name_antenna_raw = 'vhf'; % this is used as a flag for the vhf system
    name_radprog = name_expr(1:length(name_expr)-5);
  else
    disp(sprintf('analysissetup: ERROR: problem in setting name_antenna_raw'));
    exit
  end

  disp(sprintf('analysissetup: radar data-taking program name is %s',name_radprog));

% if strcmp(name_expr(length(name_expr)-2:length(name_expr)-0),'uhf')
%   name_antenna_raw = 'uhf';
% elseif strcmp(name_expr(length(name_expr)-2:length(name_expr)-0),'32m')
%   name_antenna_raw = '32m';
% elseif strcmp(name_expr(length(name_expr)-2:length(name_expr)-0),'42m')
%   name_antenna_raw = '42m';
% elseif ...
%    strcmp(name_expr(length(name_expr)-2:length(name_expr)-0),'vhf') | ...
%    strcmp(name_expr(length(name_expr)-3:length(name_expr)-1),'vhf')
%   name_antenna_raw = 'vhf'; % this is used as a flag for the vhf system
% else
%   disp(sprintf('analysissetup: ERROR: problem in setting name_antenna_raw'));
%   exit
% end

% if plain "vhf" for antenna, check program and add beam number
  if strcmp(name_expr(length(name_expr)-2:(length(name_expr))),'vhf')

    name_pulse_raw = name_expr(1:length(name_expr)-4);

    if ...
      strcmp(name_pulse_raw,'tau1_singel_v') | ...
      strcmp(name_pulse_raw,'tau1avsingle') | ...
      strcmp(name_pulse_raw,'cp7hv')
      vhf_beam = 0; % all one beam
      name_vhf_beam = '0'; % all one beam
    else % tau1av or cp4bv
      disp(sprintf('  '));
    % vhf_beam = input('VHF beam to analyze (0 = all one beam, 1 or 2): ');
      vhf_beam = input('VHF beam to analyze (1=boresight, 2=west): ');
      if vhf_beam == 1
        vhf_beam = 1;
        name_vhf_beam = '1';
      else
        vhf_beam = 2;
        name_vhf_beam = '2';
      end
    end
  % disp(sprintf('analysissetup: Analyzing VHF beam %d.',vhf_beam));
    name_expr = [ name_expr name_vhf_beam ]; % adding vhf beam number to name_expr

  end

  if strcmp(newnames(1:1),'y') % NEW NAMES (i.e. 2001 names)

    msg = 'error';
    while ~strcmp(msg,'')
    
      % using Jussi's parser to separate components of experiment name
      [msg,name_pulse,name_scan,name_comment,name_type,name_antenna] = expparts(name_expr);
      if ~strcmp(msg,'')
        disp(sprintf('analysissetup: invalid experiment name'));
      end  
      disp(sprintf('  msg     = %s',msg));
      disp(sprintf('  name    = %s',name_expr));
      disp(sprintf('  pulse   = %s',name_pulse));
      disp(sprintf('  scan    = %s',name_scan));
      disp(sprintf('  comment = %s',name_comment));
      disp(sprintf('  type    = %s',name_type));
      disp(sprintf('  antenna = %s',name_antenna));
    
    end % while

  % disp('[end of new names]');
  
  else % OLD NAMES

    if strcmp(name_antenna_raw,'vhf')
      length_name_pulse = length(name_expr)-5;
    else
      length_name_pulse = length(name_expr)-4;
    end
    name_pulse = name_expr(1:length_name_pulse);
    name_antenna = name_expr(length_name_pulse+2:length(name_expr));

    disp(sprintf('  name    = %s',name_expr));
    disp(sprintf('  pulse   = %s',name_pulse));
    disp(sprintf('  antenna = %s',name_antenna));

  % disp(sprintf('old names not yet implemented: stop'));
  % dbstop

  % disp('[end of old names]');

  end % NEW AND OLD NAMES

% name_scan, name_comment, and name_type are not presently used
    
% if strcmp(name_antenna,'vhf0') | strcmp(name_antenna,'vhf1') | strcmp(name_antenna,'vhf2')
%   if strcmp(name_antenna_raw,'vhf')
%     disp(sprintf(' '));
%     disp(sprintf('analysissetup: Resetting antenna to vhf and name to *@vhf.'));
%     name_expr = name_expr(1:length(name_expr)-1);
%     name_antenna = name_antenna(1:length(name_antenna)-1);
%     disp(sprintf('  name    = %s',name_expr));
%     disp(sprintf('  pulse   = %s',name_pulse));
%     disp(sprintf('  antenna = %s',name_antenna));
%   end
% end

% disp('[end of names]');

% check for valid pulse code and antenna combinations...
  % for the future ...
  % strcmp(name_pulse,'gup0')          & strcmp(name_antenna,'32m') | ...
  % strcmp(name_pulse,'gup0')          & strcmp(name_antenna,'42m') | ...
  % strcmp(name_pulse,'gup1')          & strcmp(name_antenna,'32m') | ...
  % strcmp(name_pulse,'gup1')          & strcmp(name_antenna,'42m') | ...
  % strcmp(name_pulse,'gup2')          & strcmp(name_antenna,'32m') | ...
  % strcmp(name_pulse,'gup2')          & strcmp(name_antenna,'42m') | ...
  % strcmp(name_pulse,'gup3')          & strcmp(name_antenna,'32m') | ...
  % strcmp(name_pulse,'gup3')          & strcmp(name_antenna,'42m') | ...
  % strcmp(name_pulse,'tau0')          & strcmp(name_antenna,'32m') | ...
  % strcmp(name_pulse,'tau0')          & strcmp(name_antenna,'42m') | ...
  if ...
    strcmp(name_pulse,'cp4bv')         & strcmp(name_antenna,'vhf') | ...
    strcmp(name_pulse,'cp4bv')         & strcmp(name_antenna,'vhf1') | ...
    strcmp(name_pulse,'cp4bv')         & strcmp(name_antenna,'vhf2') | ...
    strcmp(name_pulse,'tau1')          & strcmp(name_antenna,'vhf') | ...
    strcmp(name_pulse,'tau1')          & strcmp(name_antenna,'vhf1') | ...
    strcmp(name_pulse,'tau1')          & strcmp(name_antenna,'vhf2') | ...
    strcmp(name_pulse,'tau1v')         & strcmp(name_antenna,'vhf') | ...
    strcmp(name_pulse,'tau1v')         & strcmp(name_antenna,'vhf1') | ...
    strcmp(name_pulse,'tau1v')         & strcmp(name_antenna,'vhf2') | ...
    strcmp(name_pulse,'tau1av')        & strcmp(name_antenna,'vhf') | ...
    strcmp(name_pulse,'tau1av')        & strcmp(name_antenna,'vhf1') | ...
    strcmp(name_pulse,'tau1av')        & strcmp(name_antenna,'vhf2') | ...
    strcmp(name_pulse,'tau1avsingle')  & strcmp(name_antenna,'vhf') | ...
    strcmp(name_pulse,'tau1avsingle')  & strcmp(name_antenna,'vhf0') | ...
    strcmp(name_pulse,'tau1_singel_v') & strcmp(name_antenna,'vhf') | ...
    strcmp(name_pulse,'tau1_singel_v') & strcmp(name_antenna,'vhf0') | ...
    strcmp(name_pulse,'cp7hv')         & strcmp(name_antenna,'vhf') | ...
    strcmp(name_pulse,'cp7hv')         & strcmp(name_antenna,'vhf0') | ...
    strcmp(name_pulse,'cp1lt')         & strcmp(name_antenna,'uhf') 
    disp(sprintf('analysissetup: experiment name %s selected',name_expr));
  else
    disp(sprintf('analysissetup: ERROR: invalid pulse code + antenna combination %s: exit',name_expr));
    exit
  end

% set cp1lt code to analyze
  if strcmp(name_pulse,'cp1lt')
    if keyboard
      disp(sprintf(' '));
      codes_selected = input('cp1lt code to analyze (ac, lp, or aclp in single quotes): ');
    end % keyboard
  % check the answer
    if ...
      strcmp(codes_selected,'lp') | ...
      strcmp(codes_selected,'ac') | ...
      strcmp(codes_selected,'aclp')
    else
      disp(sprintf('analysissetup: ERROR: bad code, please start over...'));
      exit
    end
  end

% antenna_selected is full antenna name (i.e. including 0/1/2 for vhf)
% - equals name_antenna in the 2001 naming convention
% - name_antenna_raw is name_antenna without vhf beam number
  antenna_selected = name_antenna; % 
% old code with pre-2001 vhf antenna name, so beam must be added
% if strcmp(name_antenna,'vhf')
%   antenna_selected = sprintf('vhf%d',vhf_beam);
% else
%   antenna_selected = name_antenna;
% end
  if keyboard disp(sprintf(' ')); end
  disp(sprintf('analysissetup: antenna %s selected',antenna_selected));

% set raw data root
  if keyboard
    disp(sprintf(' '));
  % if strcmp(name_antenna,'uhf')
    if strcmp(name_antenna_raw,'uhf') % 20011118 bi
      rawdataroot = '/data1';
    elseif strcmp(name_antenna_raw,'vhf')
      rawdataroot = '/data2';
    else
      disp(sprintf('analysissetup: ERROR: unknown antenna %s!',name_antenna));
      exit
    end
    new_rawdataroot = rawdataroot;
    change_rawdataroot = 'y';
    disp(sprintf('Raw data root = %s',new_rawdataroot));
    change_rawdataroot = input('Change raw data root (y or n in single quotes): ');
    while ~strcmp(change_rawdataroot(1:1),'n')
      new_rawdataroot = input('New raw data root (/newname in single quotes): ');
      disp(sprintf('Raw data root = %s',new_rawdataroot));
      keep_rawdataroot = input('Keep raw data root (y or n in single quotes): ');
      if ~strcmp(keep_rawdataroot(1:1),'y')
        change_rawdataroot = 'y';
        new_rawdataroot = input('New raw data root (/name in single quotes): ');
      else
        change_rawdataroot = 'n';
      end
    end
    rawdataroot = new_rawdataroot;
    disp(sprintf(' '));
  end % keyboard
  disp(sprintf('analysissetup: raw data root = %s',rawdataroot));

% raw data path does not include vhf beam number in antenna name
% data_path = sprintf('%s/%s/',rawdataroot,name_expr);
% data_path = sprintf('%s/%s@%s/',rawdataroot,name_pulse,name_antenna_raw);
  data_path = sprintf('%s/%s@%s/',rawdataroot,name_radprog,name_antenna_raw); % 20011118 bi/mtr
  
% time interval to analyse in form [year month day hour min sec]
  if keyboard
    disp(sprintf(' '));
    disp(['Enter times in the form [YYYY MM DD HH MM SS].']);
    disp(['  Remember to include the [ ] brackets!']);
    analysis_start = input( 'Start time [in brackets]: ');
    analysis_end   = input( 'End time [in brackets]:   ');
    disp(sprintf(' '));
  end % keyboard
  disp(sprintf('analysissetup: start time = [%d %2d %2d %2d %2d %2d] ',analysis_start));
  disp(sprintf('analysissetup:   end time = [%d %2d %2d %2d %2d %2d] ',analysis_end));

% postintegration strategy defines how many seconds first to skip and integrate
% zero integration time means integrate to a move of the antenna
% the vectors are used cyclically
  if keyboard
    disp(sprintf(' '));
    disp(['Enter the integration time in the form NN seconds.']);
    disp(['  Use 00 seconds for integration to a change of direction.']);
    analysis_integr = input( 'Integration time in seconds: ');
    analysis_skip   = [ 0];  % optional, assumed to be zero if not specified
    disp(sprintf(' '));
  end % keyboard
  disp(sprintf('analysissetup: integration time = %d',analysis_integr));
  disp(sprintf('analysissetup:        skip time = %d',analysis_skip));

% integration definitions for Nigel Wade's integration

  s_time = sprintf('%d/%d/%d %d:%d:%d', analysis_start([3 2 1 4 5 6]));
  e_time = sprintf('%d/%d/%d %d:%d:%d', analysis_end([3 2 1 4 5 6]));
  dirs   = sprintf('%04d%02d??_??',     analysis_start([1 2]));
  i_time = sprintf('%2d:%02d', fix(analysis_integr/60), mod(analysis_integr,60));

% NB! The dirs definition will not let integrations continue over month boundaries!

% set integration type
  if keyboard
    disp(sprintf(' '));
    realtime = input( 'Enter 1 for real-time integration: ');
    disp(sprintf(' '));
  end % keyboard
  if realtime == 1
    disp(sprintf('analysissetup: real-time integration selected'));
  else
    disp(sprintf('analysissetup: non-real-time integration selected'));
  end

% set Guisdap site code
  if strcmp(name_antenna,'uhf')
    name_site = 'T';
  elseif strcmp(name_antenna_raw,'vhf')
    name_site = 'V';
  else
    disp(sprintf('analysissetup: ERROR: unknown antenna %s!',name_antenna));
    exit
  end

% set Guisdap source string
  if realtime == 1
    source = ['source esr day1 {       ' ...
      'start     ' s_time    ';' ...
      'directory ' data_path ';' ...
      'recurse   ' dirs      ';' ...
      'realtime  '           ';' ...
      'site      ' name_site ';' ...
      '}     ' ];
  else
    source = ['source esr day1 {       ' ...
      'start     ' s_time    ';' ...
      'directory ' data_path ';' ...
      'recurse   ' dirs      ';' ...
      'site      ' name_site ';' ...
      '}     ' ]; 
  end

% set Guisdap strategy string
  if analysis_integr([1]) > 0
  % integration for fixed time
    strategy = ['filter time { ' ...
      'start '  s_time ';' ...
      'end   '  e_time ';}' ...
      'filter power { min 100 kW; } ' ...
      'integrate time { ' ...
      'start         ' s_time  ';' ...
      'period        ' i_time  ';' ...
      '}   '];
  else
  % integration to antenna motion
    strategy = ['filter time { ' ...
      'start '  s_time ';' ...
      'end   '  e_time ';}' ...
      'filter power { min 100 kW; } ' ...
      'integrate move { }' ];
  end

% CONFIGURE THE ANALYSIS FOR ALL SUPPORTED EXPERIMENTS
  if keyboard disp(sprintf(' ')); end
  fprintf('analysissetup: calling analysisconfigure\n')
  analysisconfigure % among other things, selects codes not yet selected above
  disp(sprintf('analysissetup: codes %s selected',codes_selected));
  if keyboard disp(sprintf(' ')); end

% construct result directory name and create if necessary
% should this have name_pulse only or all except antenna?
  result_path = sprintf('/data0/analysis/%d-%02d-%02d_%s_%s_%d_%s/', ...
    analysis_start([1 2 3]), name_radprog, codes_selected, ...
    analysis_integr([1]),antenna_selected);
% result_path = sprintf('/data0/analysis/%d-%02d-%02d_%s_%s_%d_%s/', ...
%   analysis_start([1 2 3]), name_pulse, codes_selected, ...
%   analysis_integr([1]),antenna_selected);
  if ~exist( result_path )
    eval (['!mkdir ',result_path]);
  end

  disp(['analysissetup: reading from ',data_path]);  
  disp(['analysissetup: writing to   ',result_path]);  
  if keyboard disp(sprintf(' ')); end

% the initialisation files depend on name_pulse (the pulse scheme name) not name_expr
% but from pre-2001-name-convention days they are set up to utilize variable name_expr
% so...
  name_expr = name_pulse;

% go!
  analysismain_NW % formerly known as an_start or an_start_NW

