function d_gup = cp4bv2gup(d_data,do_beam)

% function rearranges signal processing output for GUISDAP
%
% /kst/exp/cp4bv/
% Matlab data file organization:
% OBS 0 INDEXED Physical channels maps 1:1 to cp4bv.tlan file
% If we have CH1 and CH1OFF this coresponds to physical channel 1
% This data comes from antenna side A
% 0 165         Signal power profile 166 samples, physical ch 1
% 166 7560      Backround lag profile 30 lags 261 samples, physical ch 1
% 7561 7618     Calibration power profile 58 samples, physical ch 1
% 7619 26323    Signal lag profile 30 lags 638 samples, physical ch 2
% This data comes from antenna side B
% 26324 26489   Signal power profile 166 samples, physical ch 4
% 26490 33884   Backround lag profile 30 lags 261 samples, physical ch 4
% 33885 33942   Calibration power profile 58 samples, physical ch 4
% 33943 52647   Signal lag profile 30 lags 638 samples, physical ch 5
%
% GUISDAP design output
% >> design
% canon: cp4bV_design
%  Xmission defined: Virtual channel 1, real channel 7
% COR_uprog:   30 lps, total    30;  638 samples, total   638; ResMem used to 18704
% COR_uprog:   30 lps, total    60;  261 samples, total   899; ResMem used to 26099
% COR_uprog:    1 lps, total    61;   58 samples, total   957; ResMem used to 26157
%  Xmission defined: Virtual channel 2, real channel 8
% COR_uprog:   30 lps, total    91;  638 samples, total  1595; ResMem used to 44862
% COR_uprog:   30 lps, total   121;  261 samples, total  1856; ResMem used to 52257
% COR_uprog:    1 lps, total   122;   58 samples, total  1914; ResMem used to 52315
%  Xmission defined: Virtual channel 3, real channel 9
% COR_uprog:    1 lps, total   123;  166 samples, total  2080; ResMem used to 52481
% COR_uprog:   30 lps, total   153;  261 samples, total  2341; ResMem used to 59876
% COR_uprog:    1 lps, total   154;   58 samples, total  2399; ResMem used to 59934
%  Xmission defined: Virtual channel 4, real channel 10
% COR_uprog:    1 lps, total   155;  166 samples, total  2565; ResMem used to 60100
% COR_uprog:   30 lps, total   185;  261 samples, total  2826; ResMem used to 67495
% COR_uprog:    1 lps, total   186;   58 samples, total  2884; ResMem used to 67553
% canon: save /opt/guisdap/exps/cp4b/cp4bV_1GUPvar.mat 
% 

%{----------------------------------------------------------------------------

    % Collect the required data from the original dump

    d_gup = zeros(67553+1,1);

    global GUP;
    global ch_az;
 
    if  isempty(GUP) 
		 GUP.s_addr{1} =  7619:26323;
		 GUP.b_addr{1} =   166: 7560;
		 GUP.c_addr{1} =  7561: 7618;
		 GUP.s_addr{2} = 33943:52647;
		 GUP.b_addr{2} = 26490:33884;
		 GUP.c_addr{2} = 33885:33942;
		 GUP.s_addr{3} =     0:  165;
		 GUP.b_addr{3} =   166: 7560;
		 GUP.c_addr{3} =  7561: 7618;
		 GUP.s_addr{4} = 26324:26489;
		 GUP.b_addr{4} = 26490:33884;
		 GUP.c_addr{4} = 33885:33942;
    end;

    d_gup_1 = [ ...
              d_data(1+GUP.s_addr{1});
              d_data(1+GUP.b_addr{1});
              d_data(1+GUP.c_addr{1});
%             d_data(1+GUP.s_addr{2});
%             d_data(1+GUP.b_addr{2});
%             d_data(1+GUP.c_addr{2});
              d_data(1+GUP.s_addr{3});
              d_data(1+GUP.b_addr{3});
              d_data(1+GUP.c_addr{3}) ...
%             d_data(1+GUP.s_addr{4});
%             d_data(1+GUP.b_addr{4});
%             d_data(1+GUP.c_addr{4}) ...
              ];

    d_gup_2 = [ ...
%             d_data(1+GUP.s_addr{1});
%             d_data(1+GUP.b_addr{1});
%             d_data(1+GUP.c_addr{1});
              d_data(1+GUP.s_addr{2});
              d_data(1+GUP.b_addr{2});
              d_data(1+GUP.c_addr{2});
%             d_data(1+GUP.s_addr{3});
%             d_data(1+GUP.b_addr{3});
%             d_data(1+GUP.c_addr{3});
              d_data(1+GUP.s_addr{4});
              d_data(1+GUP.b_addr{4});
              d_data(1+GUP.c_addr{4}) ...
              ];

  if do_beam == 0
    d_gup = d_gup_1;
    ch_az(1) = -0.5;
  elseif do_beam == 1
    d_gup = d_gup_1;
    ch_az(1) = -0.5;
  elseif do_beam == 2
    d_gup = d_gup_2;
    ch_az(1) = -15.2;
  else
    disp(['nonexistant beam selected (',do_beam,'): stop.']);
    dbstop
  end

%}init


