function tau0_L210_design  %{

%FUNCTION TAU0_L210_DESIGN
%GUISDAP design function for experiment tau0, version 2.1
%
%       IPP      
%  AC(f1) AC1(f2) 
%               
%       s1        
%       b1c1      
%       s2
%       b2c2      
%
% This version has two 16-bit x 60us alt codes, with 20 usec sampling.

% 29-Feb-2000 Jm
%===========================================================================

    Nsamples    = 366;
    Nbgrsamples = 50;
    Ninj        = 12;

    ACrfon      = [50;1070];

    Chon        = 2364;
    Tau         = 20;

    Ipp         = 10000;
    Cycle       = Ipp;
    Ncycles     = 32;

    Tunit       = 2
  % [Taps,T0]   = get_impresp('/esrsw/esr0/dsp/fir/w25d200.fir',Tunit,0);
    [Taps,T0]   = get_impresp('./w25d200.fir',Tunit,0);

    AC1          = CHANNEL(1);
    AC1.tau      = Tau;
    AC1.baud     = 3*Tau;
    AC1.fstlag   = Tau;
    AC1.maxlag   = ((8+1)*3 - 1)*Tau; 
                                      
    AC1.nbits    = 16;

    AC2          = CHANNEL(2,AC1);
    
%------------------------------------------------
    t_choff  = Chon+(Nsamples-1)*Tau
    t_calon  = t_choff+2*Tau
    t_caloff = t_calon + (Ninj-1)*Tau

%   Bwindow  = [Chon t_choff]
    Bwindow  = [t_choff - (Nbgrsamples-1)*Tau, t_choff]

    Cwindow  = [t_calon t_caloff]
    
%------------------------------------------------

    jDS_start('ESR1',2*64000,1);
    DS_set('clear');

    % Basic time unit for the design

    global p_dtau;  p_dtau = Tunit;

    % Sampling

    DS_set('adcint',Tau);

    % PDF filtering  

    DS_set('taps',Taps);

    % Cycling

    DS_set('cycle',Cycle);
    DS_set('Ncycles',Ncycles)

%------------------------------------------------------
%   AC1
%------------------------------------------------------

    % Transmission and signal reception

    TRANSMIT(AC1, ACrfon(1));

    RECEIVE(AC1, Nsamples, Chon)

    % Background and noise injection

    CALIBRATE(AC1, Bwindow, Cwindow)

    DS_set('go')

%------------------------------------------------------
%   AC2
%------------------------------------------------------

    % Transmission and signal reception

    TRANSMIT(AC2, ACrfon(2));
    RECEIVE(AC2, Nsamples, Chon)

    % Background and noise injection

    CALIBRATE(AC2, Bwindow, Cwindow)

    DS_set('go')

%}main


function TRANSMIT(X,rfon) %{
%------------------------
    if nargin ~= 2
        error('Wrong number of input arguments')
    end    
    DS_set('channel',X.ch)
    DS_set('XMITtime',rfon)
    DS_set('bitlen',X.baud)
    if X.nbits == 1
        DS_set('Npulses',1)
    else
        DS_set('Nbits',X.nbits)    
    end
%}TRANSMIT    


function CH = CHANNEL(Ch,Template) %{
%---------------------------------
    if nargin == 2
        CH = Template;
        CH.ch = Ch;
    elseif nargin == 1
        CH.ch        = Ch;
        CH.nbits     = [];
        CH.baud      = [];
        CH.tau       = [];
        CH.fstlag    = [];
        CH.maxlag    = [];
    else
        error('Wrong number of input arguments')    
    end
%}CHANNEL    


function RECEIVE(CH,N,ChOn) %{   
%-------------------------
    if nargin ~= 3
        error('Wrong number of input arguments')
    end
    if isempty(CH.ch)
        error('CH must be specified');
    end    
    if isempty(CH.nbits)
        error(EMSG(CH,'NBITS not specified'));
    end
    if isempty(CH.tau)
        error(EMSG(CH,'TAU not specified'));
    end
    if isempty(CH.fstlag)
        if CH.nbits == 1
            CH.fstlag = 0;
        else
            CH.fstlag = CH.tau;
        end        
    end
    if isempty(CH.maxlag)
        error(EMSG(CH,'MAXLAG not specified'))
    end    
    if rem(CH.fstlag,CH.tau) ~= 0
        error(EMSG(CH,'FSTLAG not an integer multiple of TAU'))
    end
    if rem(CH.maxlag,CH.tau) ~= 0
        error(EMSG(CH,'MAXLAG not an integer multiple of TAU'))
    end
    if rem(CH.baud,CH.tau) ~= 0
        error(EMSG(CH,'BAUD not an integer multiple of TAU'));
    end    

    DS_set('RECtime', ChOn);
    if CH.nbits == 1
        DS_set('gates',N);
        DS_set('lags', CH.fstlag:CH.tau:CH.maxlag);
    else
        DS_set('gates',N - (CH.nbits-1)*round(CH.baud/CH.tau)); 
        DS_set('lags', CH.fstlag:CH.tau:CH.maxlag);
    end        

%}RECEIVE


function emsg = EMSG(CH,msg) %{
%---------------------------
    if nargin ~= 2
        error('Wrong number of input arguments');
    end    
    emsg = sprintf('Ch %d: %s',CH.ch, msg);
%}EMSG    


function CALIBRATE(CH,Bwindow,Cwindow)
%-------------------------------------    
    DS_set('Bwindow',Bwindow);
    if CH.nbits == 1
        DS_set('Blags',0:CH.tau:CH.maxlag)
    else    
        DS_set('Blags',0)
    end
    DS_set('Cwindow',Cwindow);
%}CALIBRATE


