% lin_filt.m: Interpolates the linear phase filter impulse response function
% GUISDAP v.1.60 96-05-27 Copyright Asko Huuskonen and Markku Lehtinen
%
% from the values measured by Jussi Markkanen
%
% input parameters:
% BW     : desired bandwidth in kHz (EISCAT definition)
% ch     : specifies the channel numbers (optional)
% p_dtau : global time unit in us (global parameter)
% output parameters:
% impresp: the impulse response
% ch_p   : impulse resposes for channels given by ch (global)
%
% See also: but_filt, REC_impresp
%
% function impresp=lin_filt(BW,ch);
  function impresp=lin_filt(BW,ch);
  
  global ch_p p_dtau
% 
% measured impulse response of a 35.4 kHz linear phase filter.
% values given for each us.
  p_m =[ 0.001 0.005 0.017  0.045  0.090  0.150  0.220  0.291 0.355 0.403 ...
         0.432 0.438 0.422  0.387  0.339  0.282  0.223  0.166 0.115 0.073 ...
         0.040 0.017 0.003 -0.005 -0.007 -0.006 -0.004 -0.001 0.002 0.003]';
  len = length(p_m);

  dt  = 35.4/BW; % time step for the desired bandwidth

% interpolation
  p_mx= ((0:(len-1))*dt)';
  px  = (0:p_dtau:(len-1)*dt)';
  p = spline(p_mx,p_m,px);
  
% scale to get unit area and
% assign to all channels specified at input

  impresp=p/sum(p);
  if nargin==2,
   ch_p(1:length(px),ch) = impresp*ones(1,length(ch));
  end
