% load_filelist.m: checks whether data comes in EISCAT .dtst format of binary Matlab files
% GUISDAP v.1.60 96-05-27 Copyright Asko Huuskonen and Markku Lehtinen
% 
% Output parameters:
% rawdata: true if .dtst files found on the data_path
% filelist: contains the dump times, if matlab files were found 
%
% See also: integr_data integr_NW chk_par1
%
%function  [filelist,rawdata]=load_filelist
function  [filelist,rawdata]=load_filelist
 
global data_path 

OK=0; rawdata=0;
file=canon([data_path 'filelist'],0);
if exist([file,'.mat'])==2,
  OK=1;eval(canon(['load ', file, '.mat -ascii'])) 
elseif exist([file,'.dat'])==2,
  OK=1;load([file,'.dat'])
else
  files=ls(canon(data_path,0));
  if ~isempty(findstr(files,'.dtst'))
    rawdata=1; OK=1;break
  elseif isunix % One more try for unix !!!
    cmdstr=['ls ',data_path,'  | tr -cs "[0-9]" "[\012*]" | grep "[0-9]\{8\}" '];
    fprintf(' Creating filelist on the fly \n')
    [a,b]=unix(cmdstr);
    if length(b)>0
      filelist=sscanf(b,'%f');
      OK=1;
    end
  end
end

if OK & rawdata
  fprintf('*************************************************************\n')
  fprintf(' Data directory contains EISCAT raw data files\n')
  fprintf(' Data will be integrated by Nigel Wade''s integration front end\n')
  fprintf('*************************************************************\n')
elseif OK & ~rawdata
  fprintf('*************************************************************\n')
  fprintf(' Data directory contains matlab files\n')
  fprintf(' Data will be integrated by GUISDAP integration routine\n')
  fprintf('*************************************************************\n')
  filelist=diff_val(filelist);
else
  fprintf('*************************************************************\n')
  fprintf([' No data found in directory ', data_path, '\n Contents of the directory is:\n'])
  fprintf(ls(canon(data_path,0)))  
  fprintf('*************************************************************\n')
  error(' ')
end
