% mrqmn: Least squares fit routine (Marquart-Levenberg method)
% GUISDAP v.1.60 96-05-27 Copyright Asko Huuskonen and Markku Lehtinen
%
% See also: mrqmndiag
  function [aa,chi2,its,alpha,OK]=...
          mrqmn(a,ym,variance,ftol,itmax,kd2,p_coeffg,f_womega,p_om,pldfvv,errorlim)
 
  comp=a(6);a=a(1:5);
  if nargin==10, errorlim=inf; end
  OK=1;
  if min(size(variance))==1, diagonal=1;end
  if diagonal,
    invsigma=1 ./variance;
    apu=invsigma*ones(1,length(a));
  else
    % The apriori variance values for the parameters (especially for collision frequency)
    % are sometimes so low in scaled units, that a simple 
    % invsigma=inv(variance)
    % produces unnecessary warnings about the condition number of the matrix!
    % Therefore we treat the apriori part separately here.
    invsigma=diag(1./diag(variance));
    [M,N]=size(variance);
    invsigma(1:M-5,1:M-5)=inv(variance(1:M-5,1:M-5));
  end
  lambda=0.001;
  aa=a; validder=0;
  ya=dirthe([aa,comp],p_coeffg,f_womega,kd2,p_om,pldfvv);
  dyda=zeros(length(ya),length(aa));
  if diagonal,
    chi2=(ym-ya)'*(invsigma.*(ym-ya));
  else
    chi2=(ym-ya)'*invsigma*(ym-ya);
  end
  its=0;
  while its<itmax 
    if ~validder 
      its=its+1;
      for i=(1:length(aa)) 
        aa2=aa; aa2(i)=aa(i)+0.0001;
        dyda(:,i)=(ya-dirthe([aa2,comp],p_coeffg,f_womega,kd2,p_om,pldfvv))/0.0001; %calculate derivatives;
      end 
      if diagonal,
        alpha=dyda'*(apu.*dyda);
        beta=dyda'*(invsigma.*(ya-ym));
      else
        alpha=dyda'*invsigma*dyda;
        beta=dyda'*invsigma*(ya-ym);
      end
     if its==1 error=sqrt(diag(inv(alpha)));
       if error(1)>errorlim, OK=2; return,  end
     end
    end 
    da=((alpha+lambda*eye(size(alpha)))\beta)';
%    disp(da);
    chi2old=chi2; yaold=ya; aaold=aa;
    aa=aa+da;
    ya=dirthe([aa,comp],p_coeffg,f_womega,kd2,p_om,pldfvv);
    if diagonal,
      chi2=(ym-ya)'*(invsigma.*(ym-ya));
    else
      chi2=(ym-ya)'*invsigma*(ym-ya);
    end
    if chi2>=chi2old 
      chi2=chi2old; aa=aaold; ya=yaold; lambda=lambda*10; validder=1;
      if max(abs(da))<ftol, OK=0; break, end 
    else 
      lambda=lambda/10; validder=0;
      if max(abs(da))<ftol, OK=0; break, end 
    end 
  end 
end 
aa=[aa,comp];
alpha=inv(alpha);
