% mrqmndiag.m:  non-linear iteration routine of Marquart-Levenburg type
% GUISDAP v.1.60 96-05-27 Copyright Asko Huuskonen and Markku Lehtinen
%
% input arguments:
% a        : parameters to fit
% ym       : measurements
% variance : data variance, either diagonal of full
% ftol     : stop execution, when step for all paramters less than ftol
% itmax    : maximum number of iterations
% kd2 p_coeffg, f_womega, p_om, pldfvv : parameters need by dirthe 
% Output parameters
% aa    : The least-squares point
% chi2  : residual of the fit
% its   : number of iterations
% alpha : the error covariance matrix at the second last iteration point 
%
% See also: dirthe, mrqmn
%  function [aa,chi2,its,alpha]=mrqmndiag(a,ym,variance,ftol,itmax,kd2,p_coeffg,f_womega,p_om,pldfvv)
  function [aa,chi2,its,alpha]=mrqmndiag(a,ym,variance,ftol,itmax,kd2,p_coeffg,f_womega,p_om,pldfvv)
 
  warning_state=warning;
  warning off
  comp=a(6);a=a(1:5);
  if min(size(variance))==1, diagonal=1;end
  if diagonal,
    invsigma=1 ./variance;
    apu=invsigma*ones(1,length(a));
  else
    invsigma=inv(variance);
  end
  lambda=0.001;
  aa=a; validder=0;
  ya=dirthe([aa,comp],p_coeffg,f_womega,kd2,p_om,pldfvv);
  dyda=zeros(length(ya),length(aa));
  if diagonal,
    chi2=(ym-ya)'*(invsigma.*(ym-ya));
  else
    chi2=(ym-ya)'*invsigma*(ym-ya);
  end
  its=0;
  while its<itmax 
    if ~validder 
      its=its+1;
      for i=(1:length(aa)) 
        aa2=aa; aa2(i)=aa(i)+0.0001;
        dyda(:,i)=(ya-dirthe([aa2,comp],p_coeffg,f_womega,kd2,p_om,pldfvv))/0.0001; %calculate derivatives;
      end 
      if diagonal,
        alpha=dyda'*(apu.*dyda);
        beta=dyda'*(invsigma.*(ya-ym));
      else
        alpha=dyda'*invsigma*dyda;
        beta=dyda'*invsigma*(ya-ym);
      end
    end 
    da=((alpha+lambda*eye(size(alpha)))\beta)';
%    disp(da);
    chi2old=chi2; yaold=ya; aaold=aa;
    aa=aa+da;
    ya=dirthe([aa,comp],p_coeffg,f_womega,kd2,p_om,pldfvv);
    if diagonal,
      chi2=(ym-ya)'*(invsigma.*(ym-ya));
    else
      chi2=(ym-ya)'*invsigma*(ym-ya);
    end
    if chi2>=chi2old 
      chi2=chi2old; aa=aaold; ya=yaold; lambda=lambda*10; validder=1;
      if max(abs(da))<ftol, OK=0; break, end 
    else 
      lambda=lambda/10; validder=0;
      if max(abs(da))<ftol, OK=0; break, end 
    end 
  end 
aa=[aa,comp];
alpha=inv(alpha);
warning(warning_state);