% wr.m: function to calculate range ambiguity function
% GUISDAP v.1.60 96-05-27 Copyright Asko Huuskonen and Markku Lehtinen
%
% Parameters: 
% vch:    virtual channel number
% t1,t2 : sample times of first and second factor in the product
% dumdum: with four arguments calculates support for two-dimensional ambiguity
%         functions. There are cases where reduced ambiguity function is null
%         but the two-dimensional is not.
%
% See also: wrlpg
%
% function [wwr,r]=wr(vch,t1,t2,dumdum);
function [wwr,r]=wr(vch,t1,t2,dumdum);

global vc_penvabs vc_penv vc_penvo 

rt=wnz(vc_penvabs,vch);
rt=[min(rt)-1;rt;max(rt)+1];
len=length(rt); lenn=len-(t2-t1);
st=rt(1)-1;  % Origin for the part of penvabs used
wwr=vc_penv(st+(1:lenn),vch).*vc_penv(st+(1+t2-t1:len),vch);
wwr=flipud(wwr);
r=t1-vc_penvo(vch)-st+(-lenn+1:0);
if nargin>3, % calculate support for two-dim. ambiguities
  wwra=vc_penvabs(st+(1:lenn),vch).*vc_penvabs(st+(1+t2-t1:len),vch);
  wwra=flipud(wwra);
  suppind=find(wwra~=0);
  wwr=wwr(suppind); r=r(suppind);
end;
