# include <stdlib.h>
# include <stdio.h>
# include <math.h>
# include "mex.h"

#define ddabs(A) ((A)<(0) ? (-A) : (A))

#ifdef ANSI_C
	void pldfas(double *retR,double *retI,double zR,double zI,long n)
#else
void pldfas(retR,retI,zR,zI,n)
	long n;
	double *retR,*retI;
	double zR,zI;
#endif
	{
	long i;
	register double termR,termI,ckfR,ckfI,resI,resR;
	double termRold;
	ckfR = (0.5*zR*zR - 0.5*zI*zI)/(zR*zR*zR*zR + 2*zR*zR*zI*zI + zI*zI*zI*zI);
	ckfI = (-zR*zI)/(zR*zR*zR*zR + 2*zR*zR*zI*zI + zI*zI*zI*zI);
	termR = 1;
	termI = 0;				
	resR = 1;
	resI = 0;
	for (i = 1;i<=n;i++)
		{
		termR = termR*(2*i-1);
		termI = termI*(2*i-1);
		termRold = termR;
		termR = termR*ckfR - termI*ckfI;
		termI = termI*ckfR + termRold*ckfI;
		resR = resR + termR;
		resI = resI + termI;
		}
	*retR = (resR*zR + resI*zI)/(zR*zR + zI*zI);
	*retI = (-resR*zI + zR*resI)/(zR*zR + zI*zI);
	}


#ifdef ANSI_C
void pldf(double *pldfvPr,double *pldfvPi,double *retr,double *reti,double zR,double zI)
#else
void pldf(pldfvPr,pldfvPi,retr,reti,zR,zI)
double zR,zI;
double *retr,*reti,*pldfvPr,*pldfvPi;
#endif
{
	double x,y,resRo;
	register double pR,pI,resR=0,resI=0;
	register long k;
	long ix,ffx,ffy;
	
	if (zI >= 0.03125) {
		 zI = 0.03125;
	}
	if ( ( ddabs(zR) >= 3.9 ) || ( zI <= -3.5 ) ) {
		pldfas(retr,reti,zR,zI,4);
	} else {
		x = ddabs(zR)*16;
		y = -zI*16;
#ifdef MAC
		ffx=ffloor(x);
		ffy=ffloor(y+0.5);
#else
		ffx=(long)x;
		ffy=(long)(y+0.5);
#endif
		pR=x-ffx;
		pI=-(y-ffy);
		ix=(4*ffx+64*4*ffy);  
		resR = pldfvPr[ix];
		resI = pldfvPi[ix];
		
		for (k=1; k<=3; k++) {
		resRo = resR;
		resR = resR * pR - resI * pI + pldfvPr[ix+k];
		resI = resRo * pI + resI * pR + pldfvPi[ix+k];}

		*reti = resI;
		if (zR<0) *retr = -resR; else *retr = resR;		
	}
}
#ifdef ANSI_C
void specCalc(double *pldfvPr,double *pldfvPi,double *nin0Pr,double *tit0Pr,long ns,long nion,double *mim0Pr,
			  double *psiPr,double *viPr,double *kd2Pr,long nom,double *omPr,double *resPr)
#else
void specCalc(pldfvPr,pldfvPi,nin0Pr,tit0Pr,ns,nion,mim0Pr,psiPr,viPr,kd2Pr,nom,omPr,resPr)
long ns,nion,nom;
double *pldfvPr,*pldfvPi,*nin0Pr,*tit0Pr,*mim0Pr,*psiPr,*viPr,*kd2Pr,*omPr,*resPr;
#endif
{
	Matrix *gam,*gamn,*npert;
	unsigned long i,k;
	long is,is_i;
	register double apupr,apupi;
	register double apusqr;
	register double apuuapr;
	double oma;
	double uar, uai;
	double yars, yais;
	double uars;

	double *gamPr,*gamnPr,*npertPr;
	
	gam = mxCreateFull(ns, nion+1, REAL);
	npert = mxCreateFull(ns, nion+1, REAL);
	gamn = mxCreateFull(ns, nion+1, REAL);

	gamPr = mxGetPr(gam);
	gamnPr = mxGetPr(gamn);
	npertPr = mxGetPr(npert);


	for (is=0;is<ns;is++) {
		
		for(i=0;i<(nion+1);i++) {
			is_i=is+ns*i;
			gamPr[is_i] = sqrt(mim0Pr[is_i]/tit0Pr[is_i]); 
			npertPr[is_i] = (nin0Pr[is_i]/tit0Pr[is_i]); 
			gamnPr[is_i] = gamPr[is_i] * nin0Pr[is_i]; }


		for(k=0;k<nom;k++) {
			yais= kd2Pr[is];
			yars= 0; uars=0;


			for (i=0;i<(nion+1);i++) {
			  is_i=is+ns*i;
			  if ( nin0Pr[is_i] > 0.0000001 ) {
				oma = (omPr[k] - viPr[is_i])* gamPr[is_i];
				pldf(pldfvPr,pldfvPi,&uar, &uai, oma, -psiPr[is_i]);
				apupr = 1 - psiPr[is_i]*uai;
				apupi = -(psiPr[is_i])*uar;
				apusqr = apupr*apupr + apupi*apupi;
				apuuapr = apupr;
				apupr = (uai*apupr  +  apupi * uar)/apusqr;
				apupi = (uai*apupi  -  apuuapr * uar)/apusqr;
				if (i<nion) {
					uars += apupr * gamnPr[is_i];
					yars += (oma * apupr) * npertPr[is_i];
					yais += (1 + oma * apupi) * npertPr[is_i];
				} else {
				/* yar */ apusqr = (oma * apupr) * npertPr[is_i];
				/* yai */ apuuapr = (1 + oma * apupi) * npertPr[is_i];
				uar = apupr * gamnPr[is_i];
				}
			  }
			}
			
			apupr = apusqr + yars;				
			apupi = apuuapr + yais;
			resPr[k+nom*is] = ( (apusqr * apusqr  +  apuuapr * apuuapr)  *  uars  + (yars * yars  +  yais * yais)  *  uar ) /(apupr * apupr +  apupi * apupi)/3.1415926535897932385;
		}
   	}
	}
