proc add_driver { driver } {

global drivers_selected
global driver_path
global interface_path
global widgets
global driver_extension
global strategy_needs_save
global LIBDIR

    # convert spaces in the driver name to _
    set translit_driver [translit " " "_" $driver]
    
    # if the command to display the dialog box for the current
    # driver is already installed then just run it
    # it may be installed in its own name, or with a _ui
    # appended if the interface was created with specTcl.
    #
    # if the command does not exists then look for a tcl source
    # file either in the current directory or in the driver
    # install directory which contains the code for the
    # driver interface.
    
    if { [llength [info commands ${translit_driver}]] == 1 || \
         [llength [info commands ${translit_driver}_ui]] == 1 } {

    } elseif { [file exists ${translit_driver}.tcl] } {
	source ${translit_driver}.tcl
    } elseif { [file exists ${translit_driver}.ui.tcl] } {
	source ${translit_driver}.ui.tcl

    } elseif { [file exists ${interface_path}/${translit_driver}.tcl] } {
	source ${interface_path}/${translit_driver}.tcl
    } elseif { [file exists ${interface_path}/${translit_driver}.ui.tcl] } {
	source ${interface_path}/${translit_driver}.ui.tcl

    } elseif { [file exists ${driver_path}/${translit_driver}.tcl] } {
	source ${driver_path}/${translit_driver}.tcl
    } elseif { [file exists ${driver_path}/${translit_driver}.ui.tcl] } {
	source ${driver_path}/${translit_driver}.ui.tcl

    } elseif { [file exists ${LIBDIR}/${translit_driver}.tcl] } {
	source ${LIBDIR}/${translit_driver}.tcl
    } elseif { [file exists ${LIBDIR}/${translit_driver}.ui.tcl] } {
	source ${LIBDIR}/${translit_driver}.ui.tcl

    } else {
	error_message "Unable to locate interface specification file\n" "for driver \"$driver\""
	status_message " No configuration driver for \"$driver\""
	return
    }

    set ndrivers [llength $drivers_selected]
    
    # determine if there is a "gap" in the driver list, this
    # is generated by the insert menu on the driver buttons and
    # is indicated by the value of "insert" in the list of drivers.
    for {set index 0} {$index < $ndrivers} {incr index} {
	if { [lindex [lindex $drivers_selected $index] 0] == "insert" } {
	    break
	}
    }

    set gridsize [grid size $widgets(driver_frame)]

    set ncolumns [lindex $gridsize 0]
    set nrows [lindex $gridsize 1]
    
    set column [expr $index +2]
    set row 1
    while { $column > 6 } {
	incr row 1
	incr column -6
    }


    # create the new button
    if { $index != $ndrivers } {
	set button_name [lindex [lindex $drivers_selected $index] 2]
	catch { regexp \[0-9\]+\$ $button_name driver_number }
	set root .${translit_driver}_$driver_number
	$button_name configure -text "$driver" -relief raised \
    	    -activebackground #ececec  \
	    -background grey -state normal -padx 5 -pady 5
	set drivers_selected [lreplace $drivers_selected $index $index [list $driver $root $button_name]]
    } else {
	set root .${translit_driver}_$driver_extension
	set button_name $widgets(driver_frame).driver_button$driver_extension
	menubutton $button_name -text "$driver" -relief raised \
    	    -activebackground #ececec -menu $button_name.menu \
	    -background grey -state normal -padx 5 -pady 5
	lappend drivers_selected [list $driver $root $button_name]
	incr driver_extension
    }
    
    menu $button_name.menu
    $button_name.menu add command -label Configure... \
	-command "configure_driver \"$driver\" $root"
    $button_name.menu add command -label Insert \
	-command "insert_driver $root"
    $button_name.menu add separator
    $button_name.menu add command -label Delete \
	-command "delete_driver \"$driver\" $root"

    grid $button_name -in $widgets(driver_frame) -row $row -column $column -sticky w

    # re-grid the driver_frame to prevent the new button from expanding
    grid rowconfigure $widgets(driver_frame) $row -minsize 30 -weight 0 -pad 1
    if { $row >= [expr $nrows -1] } {
	grid rowconfigure $widgets(driver_frame) $nrows -minsize 0 -weight 1 -pad 1
    }
    grid columnconfigure $widgets(driver_frame) $column -weight 0 -minsize 30 -pad 1
    if { $column >= [expr $ncolumns -1] } {
	grid columnconfigure $widgets(driver_frame) $ncolumns -weight 1 -minsize 0 -pad 1
    }
    
    set strategy_needs_save 1
    configure_driver "$driver" $root
    
}
