# function to load a source definition file
proc open_source { {source ""} } {

global widgets
global source_selected
global source_needs_save
global source_filename
global interface_path

    if { $source_selected != "" && $source_needs_save } {
	set answer [choice_message {"Save & Load" "Load" "Cancel"} "The current source driver has been modified.\n" "What do you want to do?"]
	if { "$answer"  == "Cancel" } {
	    status_message "Source not changed"
	    return -1
	}
	if { "$answer"  == "Save & Load" } {
	    if { [save_source] != 0 } {
		error_message "Failed to save the current source strategy"
		status_message "Failed to save the current source strategy"
		return -1
	    }
	}
    }
    
    set source_needs_save 0
    
    if { $source == "" } {
	status_message "Choose a source driver file to load..."
	set source [tk_getOpenFile -title "Load ..." -filetypes {{{Source definition files} {.sdef}} {{Any file} {*}}}]
	if { $source == "" } { 
	    status_message "Source not changed"
	    return -1
	}
    }
    set source_filename $source
    
    if { [catch {exec load_driver -s $source} results] != 0 } {
	error_message "Failed to parse the source\n$source\n$results"
	status_message "Failed to parse the source"
	return -1
    }

    set driver [lindex [lindex $results 0] 0]
    
    if { $source_selected != "" && $source_selected != $driver } {
	if { [choice_message {"Yes" "No"} "Do you want to change the source from\n" "\"[lindex $source_selected 0]\" to \"$driver\"?"] != "Yes" } {
	    status_message "Source not changed"
	    return
	}
    }

    foreach name [array names driver_tmp ".source*"] {
	unset driver_tmp($name)
    }
    foreach name [array names driver_data ".source*"] {
	unset driver_data($name)
    }
    
    # convert spaces in the driver name to _
    set translit_driver [translit " " "_" $driver]
    set root .${translit_driver}
    
    
    # if the command to display the dialog box for the current
    # driver is already installed then just run it
    # it may be installed in its own name, or with a _ui
    # appended if the interface was created with specTcl.
    #
    # if the command does not exists then look for a tcl source
    # file either in the current directory or in the driver
    # install directory which contains the code for the
    # driver interface.
    
    if { [llength [info commands ${translit_driver}]] == 1 || \
         [llength [info commands ${translit_driver}_ui]] == 1 } {
    } elseif { [file exists ${translit_driver}.tcl] } {
	source ${translit_driver}.tcl
    } elseif { [file exists ${translit_driver}.ui.tcl] } {
	source ${translit_driver}.ui.tcl
    } elseif { [file exists ${interface_path}/${translit_driver}.tcl] } {
	source ${interface_path}/${translit_driver}.tcl
    } elseif { [file exists ${interface_path}/${translit_driver}.ui.tcl] } {
	source ${interface_path}/${translit_driver}.ui.tcl
    } else {
	error_message "Unable to locate interface specification file\n" "for driver \"$driver\""
	status_message " No configuration driver for \"$driver\""
	return -1
    }

    $widgets(source_button) configure -text $driver -relief raised \
    	-activebackground #ececec -command "configure_driver \"$driver\" $root" \
    	-state normal
    
    set source_selected [list $driver $root]

    if { [catch {${translit_driver}_set_values $root [lrange [lindex $results 0] 1 end]} set_result] != 0 } {
	error_message "Error initializing interface for $driver\n$set_result"
    }

    status_message Ok
    return 0
}    
