# function to load a strategy definition file
proc open_strategy { {strategy ""} } {

global drivers_selected
global interface_path
global widgets
global driver_extension
global strategy_needs_save
global driver_tmp
global driver_data
global strategy_filename

    if { $drivers_selected != "" } {
	if { [choice_message {"Yes" "No"} "Do you want to change the strategy?"] != "Yes" } {
	    status_message "Strategy not changed"
	    return
	}
    }

    if { $drivers_selected != "" && $strategy_needs_save } {
	set answer [choice_message {"Save & Load" "Load" "Cancel"} "The current strategy has been modified.\n" "What do you want to do?"]
	if { "$answer"  == "Cancel" } {
	    status_message "Strategy not changed"
	    return -1
	}
	if { "$answer"  == "Save & Load" } {
	    if { [save_strategy] != 0 } {
		error_message "Failed to save the current strategy"
		return -1
	    }
	}
    }
    
    set strategy_needs_save 0
    
    if { $strategy == "" } {
	status_message "Choose a strategy driver file to load..."
	set strategy [tk_getOpenFile -title "Load ..." -filetypes {{{Strategy definition files} {.idef}} {{Any file} {*}}}]
	if { $strategy == "" } { 
	    status_message "Strategy not changed"
	    return -1
	}
    }
    set strategy_filename $strategy
    
    if { [catch {exec load_driver -i $strategy} results] != 0 } {
	error_message "Failed to parse the strategy \n$strategy\n$results"
	status_message "Failed to parse the strategy"
	return -1
    }

    set source_array [array get driver_tmp ".source*"]
    catch {unset driver_tmp}
    if { [llength $source_array] > 0 } {
	array set driver_tmp $source_array
    }
    set source_array [array get driver_data ".source*"]
    catch {unset driver_data}
    if { [llength $source_array] > 0 } {
	array set driver_data $source_array
    }
    
    foreach driver $drivers_selected {
	catch {destroy [lindex $driver 1]}
	catch {destroy [lindex $driver 2]}
    }
    set drivers_selected {}
    set driver_extension 0

    foreach strategy $results {
    
	set driver [lindex $strategy 0]
	
	# convert spaces in the driver name to _
	set translit_driver [translit " " "_" $driver]
	set root .${translit_driver}

	set ndrivers [llength $drivers_selected]

	for {set index 0} {$index < $ndrivers} {incr index} {
	    if { [lindex [lindex $drivers_selected $index] 0] == "insert" } {
		break
	    }
	}

	set root .${translit_driver}_$driver_extension

	if { [llength [info commands ${translit_driver}]] == 1 || \
             [llength [info commands ${translit_driver}_ui]] == 1 } {
	} elseif { [file exists ${translit_driver}.tcl] } {
	    source ${translit_driver}.tcl
	} elseif { [file exists ${translit_driver}.ui.tcl] } {
	    source ${translit_driver}.ui.tcl
	} elseif { [file exists ${interface_path}/${translit_driver}.tcl] } {
	    source ${interface_path}/${translit_driver}.tcl
	} elseif { [file exists ${interface_path}/${translit_driver}.ui.tcl] } {
	    source ${interface_path}/${translit_driver}.ui.tcl
	} else {
	    error_message "Unable to locate interface specification file\n" "for driver \"$driver\""
	    status_message " No configuration driver for \"$driver\""
	    return
	}

	set gridsize [grid size $widgets(driver_frame)]

	set ncolumns [lindex $gridsize 0]
	set nrows [lindex $gridsize 1]

	set column [expr $index +2]
	set row 1
	while { $column > 6 } {
	    incr row 1
	    incr column -6
	}

	# create the new button
	if { $index != $ndrivers } {
	    set button_name [lindex [lindex $drivers_selected $index] 2]
	    $button_name configure -text "$driver" -relief raised \
    		-activebackground #ececec  \
		-background grey -state normal -padx 5 -pady 5
	    set drivers_selected [lreplace $drivers_selected $index $index [list $driver $root $button_name]]
	} else {
	    set button_name $widgets(driver_frame).driver_button$driver_extension
	    menubutton $button_name -text "$driver" -relief raised \
    		-activebackground #ececec -menu $button_name.menu \
		-background grey -state normal -padx 5 -pady 5
	    lappend drivers_selected [list $driver $root $button_name]
	}

	menu $button_name.menu
	$button_name.menu add command -label Configure... \
	    -command "configure_driver \"$driver\" $root"
	$button_name.menu add command -label Insert \
	    -command "insert_driver $root"
	$button_name.menu add separator
	$button_name.menu add command -label Delete \
	    -command "delete_driver \"$driver\" $root"

	grid $button_name -in $widgets(driver_frame) -row $row -column $column -sticky w

	# re-grid the driver_frame to prevent the new button from expanding
	grid rowconfigure $widgets(driver_frame) $row -minsize 30 -weight 0 -pad 1
	if { $row >= [expr $nrows -1] } {
	    grid rowconfigure $widgets(driver_frame) $nrows -minsize 0 -weight 1 -pad 1
	}
	grid columnconfigure $widgets(driver_frame) $column -weight 0 -minsize 30 -pad 1
	if { $column >= [expr $ncolumns -1] } {
	    grid columnconfigure $widgets(driver_frame) $ncolumns -weight 1 -minsize 0 -pad 1
	}

	incr driver_extension

	if { [catch {${translit_driver}_set_values $root [lrange $strategy 1 end]} set_result] != 0 } {
	    error_message "Error initializing interface for $driver\n$set_result"
	}
    
    }
    status_message Ok
    return 0
}    
