% chk_par1: Interface betwen the user supplied and internal control parameters 
% GUISDAP v.1.60 96-05-27 Copyright Asko Huuskonen and Markku Lehtinen
% 
% chk_par1 is the main interface between the user supplied control parameters and
% the internal GUISDAP control parameters. There is mostly a one-to-one correspondence
% between the parameters e.g.
% User parameter   GUISDAP parameter
% analysis_altit    a_altit
% analysis_integr   a_integr
% display_figures   di_figures
% integ_deffile     a_integdeffile
% The user parameters are local to the workspace whereas the GUISDAP parameters are global
% If any of the user parameters is not specified, or empty, the corresponding GUISDAP
% parameter will get the values specified in the routine.
%
% See also: an_start globals chk_par2 load_filelist

globals

len=length(result_path); 
if len>0,  char=result_path(len);
if char~=':' & char~='/' & char~='\', result_path(len+1)='/';end; end

len=length(path_GUP); char=path_GUP(len);
if char~=':' & char~='/' & char~='\', path_GUP(len+1)='/';end

len=length(path_exps); char=path_exps(len);
if char~=':' & char~='/' & char~='\', path_exps(len+1)='/';end

len=length(path_tmp); char=path_tmp(len);
if char~=':' & char~='/' & char~='\', path_tmp(len+1)='/';end

% The first if-block tries to locate the data source and produces variables 
% necessary for integration:
a_simul=[]; % If this variable present, the data is produced from theory (So clear it)
% The first 'if' looks for the integration definition file for Nigel Wade's integration
% package. If this variable is present and the file exists, the data comes through that package.

    a_rawdata=1; % This flags that NW's package is to be used
    fprintf('*************************************************************\n')
    fprintf(' Data will be integrated by Nigel Wade''s integration front end\n')
    fprintf('*************************************************************\n')

a_control=[100000, 0.01, 6 1];
% a_control(1)  No fit is tried, if the error of Ne is larger than (1) at the start
% a_control(2)  Fitting is stopped when step for all parameters is less than (2)
% a_control(3)  Maximum number of iterations
% a_control(4)  Variance calculation
%               = 1 when variance estimated from data
%               = 2 when variance estimated using ambiguity functions
if exist('analysis_control')
  ind=find(analysis_control>0);
  a_control(ind)=analysis_control(ind);
end
if any(a_simul) & a_control(4)==1
  a_control(4)=2;
end

a_Magic_const=1;
if exist('Magic_const')
  a_Magic_const=Magic_const;
end
  

di_figures=[1 1 1 1]; 
if exist('display_figures'), 
  di_figures(1:length(display_figures))=display_figures;
end
if exist('display_fit'),  % For compatibility with GUISDAP 1.44 and earlier    
  di_figures(3)=display_fit; 
end
if exist('display_results'), % For compatibility with GUISDAP 1.44 and earlier    
  di_figures(4)=display_results; 
end



