% integr_NW: Interface to Nigel Wade's integration package (mex call)
% GUISDAP v1.60   96-05-27 Copyright Asko Huuskonen, Markku Lehtinen
% 
% Interface to Nigel Wade's integration package (mex call)
% Parameters:
% a_integdeffile : the integration definition file
% OK  : if true, the integration was succesful
% EOF : if true, the end of file was found during integration
% global parameters:
% d_parbl : the parameter block returned by the integration program
% d_data : the integrated data vector
% d_var1 d_var2: data variances
%
% See also: an_start integr_data integrate
%
% function [OK,EOF]=integr_NW
%
%
% NOTE: This is a copy of the EISCAT interface to NW:s package
% Please check that the call sequence has not changed
% and change this file accordingly
% Then comment the following line

function [OK,EOF]=integr_NW

global d_parbl d_data d_var1 d_var2 a_control 
global iHandle source strategy trace_level


if isempty(iHandle),
  if ~exist('source') | ~exist('strategy'),
    fprintf('Must specify a source and strategy for integration\n');
    EOF=1; OK=0;
    return;
  end
  if isempty(source) | isempty(strategy),
    fprintf('source and strategy cannot be empty matrices\n');
    EOF=1; OK=0;
    return;
  end

  if exist('trace_level'),
    [status,iHandle] = PI_init(source,strategy,'',trace_level); 
  else
    [status,iHandle] = PI_init(source,strategy,'');
  end
end 
[status,dHandle,modes] = PI_next(iHandle,1);
  

EOF=0;
if status ~= 0,
  es=error_string(status);
  if es ~= 'no more data in source',
    OK=0; 
    fprintf(' Error in integration - %s \n',error_string(status)); 
    return
  end
  EOF=1;
end

[status1,data]=PI_mode_data(dHandle,0);
[status2,var1,var2]=PI_mode_var(dHandle,0);
[status3,n_records,count]=PI_mode_count(dHandle,0);
[status4,st,ss,et,es]=PI_data_time(dHandle);
[status5,power]=PI_mode_power(dHandle,0);
[status6,sp,cp,ep]=PI_beam_point(dHandle,0);
[status]=PI_free(dHandle);

if status1 ~= 0 | status2 ~= 0 | status3 ~= 0 | status4 ~= 0,
  fprintf(' error extracting data from data handle\n')
  OK=0; EOF=0;
  return;
end

if isempty(var1) | isempty(var2),
  fprintf(' no variances in the data\n')
  OK=0; EOF=0;
  return;
end


d_parbl(1:6) = datevec(es);
d_parbl(7) = et(1) - st(1);
d_parbl(8) = power;
d_parbl(9) = sp(2);
d_parbl(10) = sp(1);
d_parbl(11:21) = [0 0 0 0 0 0 0 0 0 0 0];

if isempty(count),
  total = n_records;
else,
  total = count;
end

  if a_control(4)==1 & n_records<2,
    fprintf(' One file is not enough for variance determination\n')
    fprintf(' Skipping this integration period\n')
    fprintf(' command ''analysis_control(4)=2'' in the startup file will enable the analysis\n')
    OK=0;
    return
  elseif a_control(4)==1 & n_records<5,
    fprintf(' *******************    WARNING    **********************************\n')
    fprintf(' %.0f files may not be enough for reliable variance determination\n',n_records)
    fprintf(' *******************    WARNING    **********************************\n')
  end


d_data = n_records * data(:) ./ total;
d_var1 = var1(:) - d_data .* d_data ./ total;
d_var2 = var2(:) - d_data .* conj(d_data) ./ total;

OK=1;
